<?php

namespace App\Http\Controllers\Admin;

use Illuminate\Http\Request;
use App\Http\Controllers\Controller;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Storage;
use Symfony\Component\HttpFoundation\Response;
use Notification;
use Illuminate\Support\Facades\Auth;

use App\Category;

class CategoryController extends Controller
{
    //Mètode per mostrar la pàgina de crear una categoria
    public function createCategory(){
        return view('admin.posts.createCategory');
    }

    //Mètode per guardar una categoria
    public function saveCategory(Request $request){
        //Validar formulari
        $validateData = $this->validate($request, [
            'name' => 'required',
        ]);

        $category = new Category();
        $category->name = $request->input('name');
        $category->slug = str_slug($request->input('name'));
        $category->description = $request->input('description');

        $category->save();

        Notification::success('Categoria creada correctament.');

        return back();
    }

    //Mètode per llistar les categories
    public function getCategories(){
        $categories = Category::simplePaginate(10);

        return view('admin.posts.categories', array(
            'categories' => $categories,
        ));
    }

    //Mètode per editar una categoria
    public function editCategory($category_id){
        $category = Category::find($category_id);

        if (Auth::user()->hasRole('admin')) {
            return view('admin.posts.editCategory', array(
                'category' => $category,
            ));
        } else {
            return redirect()->route('categories');
        }
    }

    //Mètode per actualitzar uina categoria
    public function updateCategory($category_id, Request $request){
        //Validar formulari
        $validateData = $this->validate($request, [
            'name' => 'required',
        ]);

        $category = Category::find($category_id);
        $category->name = $request->input('name');
        $category->slug = str_slug($request->input('name'));
        $category->description = $request->input('description');
        $category->save();

        $categories = Category::simplePaginate(10);

        Notification::success('Categoria actualitzada correctament.');

        return redirect()->route('getCategories', ['categories' => $categories]);
    }

    //Mètode per eliminar una categoria
    public function deleteCategory($category_id){
        $category = Category::find($category_id);

        if (Auth::user()->hasRole('admin')) {
            $category->delete();
            Notification::success('Categoria eliminada correctament.');
        } else {
            Notification::success("La categoria no s'ha pogut eliminar correctament.");
        }

        return redirect()->route('getCategories');
    }
}
