<?php

namespace App\Http\Controllers\Admin;

use Illuminate\Http\Request;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Storage;
use PHPUnit\Util\Type;
use Symfony\Component\Debug\Debug;
use Symfony\Component\HttpFoundation\Response;
use Illuminate\Support\Facades\Auth;
use Notification;
use Debugbar;
use Illuminate\Support\Facades\Redirect;
use App\Http\Controllers\Controller;
use App\Pet;
use App\User;
use App\TypePet;
use App\StatusPet;
use App\Province;
use App\City;

class PetController extends Controller
{
    //Mètode que mostra la pàgina per crear una mascota
    public function createPet($user_id){
        $typesPet = TypePet::all();
        $statusPets = StatusPet::all();
        $user = User::find($user_id);

        return view('admin.pets.createPet', array(
            'statusPets' => $statusPets,
            'typesPet' => $typesPet,
            'user' => $user,
            'user_id' => $user_id,
        ));
    }

    //Mètode que guarda una mascota
    public function savePet($user_id, Request $request){
        //Validar formulari
        $validateData = $this->validate($request, [
            'name' => 'required|string|max:20',
            'typePet' => 'required',
            'breed' => 'required|string|max:20',
            'birthday' => 'required',
            'gender' => 'required|string|max:20',
            'size' => 'required|string|max:20',
            'weight' => 'numeric|required',
            'statusPet' => 'required',
            'editordata' => 'required',
            'image' => 'required|mimes:jpeg,png,bmp'
        ]);

        $user_id = $request->input('id');
        $pet = new Pet();
        $typePet_Slug = $request->input('typePet');
        $typePet = DB::table('type_pets')
            ->where('slug', $typePet_Slug)->get();
        $statusPet_Slug = $request->input('statusPet');
        $statusPet = DB::table('status_pets')
            ->where('slug', $statusPet_Slug)->get();
        $pet->user_id = $user_id;
        $pet->name = $request->input('name');
        $pet->slug = str_slug($request->input('name'));
        $pet->typePet_id = $typePet[0]->id;
        $pet->breed = $request->input('breed');
        $pet->birthday = $request->input('birthday');
        $pet->gender = $request->input('gender');
        $pet->size = $request->input('size');
        $pet->weight = $request->input('weight');
        $pet->health = $request->input('name');
        $pet->statusPet_id = $statusPet[0]->id;
        $pet->color = $request->input('color');
        $pet->description = $request->input('editordata');

        //Imatge
        $image = $request->file('image');
        if ($image) {
            $image_path = time() . $image->getClientOriginalName();
            \Storage::disk('images')->put($image_path, \File::get($image));
            $pet->image = $image_path;
        }

        $pet->save();

        Notification::success('Mascota creada correctament.');

        return redirect()->route('getUsers');
    }

    //Mètode per llistar les mascotes
    public function getPets($search = null, Request $request){
        if (is_null($search)) {
            $search = \Request::get('search');
        }

        $order = $request->input('ordenar');
        if (empty($order)) {
            $order = 'mes-recents';
        }

        $field = 'pets.id';
        $direction = 'desc';

        if ($order == 'mes-recents') {
            $field = 'pets.id';
            $direction = 'desc';
        }
        if ($order == 'mes-antigues') {
            $field = 'pets.id';
            $direction = 'asc';
        }
        if ($order == 'a-z') {
            $field = 'pets.name';
            $direction = 'asc';
        }
        if ($order == 'z-a') {
            $field = 'pets.name';
            $direction = 'desc';
        }

        $especie = $request->input('especie');
        if (empty($especie)) {
            $especie = 'totes';
        } else {
            $especieFilter = DB::table('type_pets')
                ->where('slug', '=', $especie)
                ->take(1)
                ->get();
        }

        $status_slug = $request->input('estat');

        if (empty($status_slug)) {
            $status_slug = 'tots';
        } else {
            $status_id = DB::table('status_pets')
                ->where('slug', '=', $status_slug)->get();
        }

        $typesPet = TypePet::all();
        $statusPets = StatusPet::all();

        if (!isset($search) && empty($search)) {
            Debugbar::addMessage('No hi ha cerca');

            if ($especie == 'totes' && $status_slug != 'tots') {
                $especieFilter = null;
                $pets = DB::table('pets')
                    ->leftJoin('users', 'pets.user_id', '=', 'users.id')
                    ->leftJoin('provinces', 'users.provinces_id', '=', 'provinces.id')
                    ->leftJoin('cities', 'users.cities_id', '=', 'cities.id')
                    ->leftJoin('type_pets', 'pets.typePet_id', '=', 'type_pets.id')
                    ->leftJoin('status_pets', 'pets.statusPet_id', '=', 'status_pets.id')
                    ->where('pets.statusPet_id', '=', $status_id[0]->id)
                    ->select('pets.id', 'pets.name', 'pets.breed', 'type_pets.type', 'pets.image', 'provinces.province', 'cities.city', 'status_pets.status')
                    ->orderBy($field, $direction)
                    ->simplePaginate(12);

            } else if ($especie != 'totes' && $status_slug == 'tots') {
                $pets = DB::table('pets')
                    ->leftJoin('users', 'pets.user_id', '=', 'users.id')
                    ->leftJoin('provinces', 'users.provinces_id', '=', 'provinces.id')
                    ->leftJoin('cities', 'users.cities_id', '=', 'cities.id')
                    ->leftJoin('type_pets', 'pets.typePet_id', '=', 'type_pets.id')
                    ->leftJoin('status_pets', 'pets.statusPet_id', '=', 'status_pets.id')
                    ->where('pets.typePet_id', '=', $especieFilter[0]->id)
                    ->select('pets.id', 'pets.name', 'pets.breed', 'type_pets.type', 'pets.image', 'provinces.province', 'cities.city', 'status_pets.status')
                    ->orderBy($field, $direction)
                    ->simplePaginate(12);

            } else if ($especie == 'totes' && $status_slug == 'tots') {
                $especieFilter = null;
                $pets = DB::table('pets')
                    ->leftJoin('users', 'pets.user_id', '=', 'users.id')
                    ->leftJoin('provinces', 'users.provinces_id', '=', 'provinces.id')
                    ->leftJoin('cities', 'users.cities_id', '=', 'cities.id')
                    ->leftJoin('type_pets', 'pets.typePet_id', '=', 'type_pets.id')
                    ->leftJoin('status_pets', 'pets.statusPet_id', '=', 'status_pets.id')
                    ->select('pets.id', 'pets.name', 'pets.breed', 'type_pets.type', 'pets.image', 'provinces.province', 'cities.city', 'status_pets.status')
                    ->orderBy($field, $direction)
                    ->simplePaginate(12);

            } else {
                $pets = DB::table('pets')
                    ->leftJoin('users', 'pets.user_id', '=', 'users.id')
                    ->leftJoin('provinces', 'users.provinces_id', '=', 'provinces.id')
                    ->leftJoin('cities', 'users.cities_id', '=', 'cities.id')
                    ->leftJoin('type_pets', 'pets.typePet_id', '=', 'type_pets.id')
                    ->leftJoin('status_pets', 'pets.statusPet_id', '=', 'status_pets.id')
                    ->where('pets.typePet_id', '=', $especieFilter[0]->id)
                    ->where('pets.statusPet_id', '=', $status_id[0]->id)
                    ->select('pets.id', 'pets.name', 'pets.breed', 'type_pets.type', 'pets.image', 'provinces.province', 'cities.city', 'status_pets.status')
                    ->orderBy($field, $direction)
                    ->simplePaginate(12);
            }
        } else {
            if ($especie == 'totes' && $status_slug != 'tots') {
                $especieFilter = null;
                $pets = DB::table('pets')
                    ->leftJoin('users', 'pets.user_id', '=', 'users.id')
                    ->leftJoin('provinces', 'users.provinces_id', '=', 'provinces.id')
                    ->leftJoin('cities', 'users.cities_id', '=', 'cities.id')
                    ->leftJoin('type_pets', 'pets.typePet_id', '=', 'type_pets.id')
                    ->leftJoin('status_pets', 'pets.statusPet_id', '=', 'status_pets.id')
                    ->where('pets.statusPet_id', '=', $status_id[0]->id)
                    ->where('pets.name', 'LIKE', '%' . $search . '%')
                    ->orWhere('pets.id', 'LIKE', '%' . $search . '%')
                    ->select('pets.id', 'pets.name', 'pets.breed', 'type_pets.type', 'pets.image', 'provinces.province', 'cities.city', 'status_pets.status')
                    ->orderBy($field, $direction)
                    ->simplePaginate(12);

            } else if ($especie != 'totes' && $status_slug == 'tots') {
                $pets = DB::table('pets')
                    ->leftJoin('users', 'pets.user_id', '=', 'users.id')
                    ->leftJoin('provinces', 'users.provinces_id', '=', 'provinces.id')
                    ->leftJoin('cities', 'users.cities_id', '=', 'cities.id')
                    ->leftJoin('type_pets', 'pets.typePet_id', '=', 'type_pets.id')
                    ->leftJoin('status_pets', 'pets.statusPet_id', '=', 'status_pets.id')
                    ->where('pets.typePet_id', '=', $especieFilter[0]->id)
                    ->where('pets.name', 'LIKE', '%' . $search . '%')
                    ->orWhere('pets.id', 'LIKE', '%' . $search . '%')
                    ->select('pets.id', 'pets.name', 'pets.breed', 'type_pets.type', 'pets.image', 'provinces.province', 'cities.city', 'status_pets.status')
                    ->orderBy($field, $direction)
                    ->simplePaginate(12);

            } else if ($especie == 'totes' && $status_slug == 'tots') {
                $especieFilter = null;
                $pets = DB::table('pets')
                    ->leftJoin('users', 'pets.user_id', '=', 'users.id')
                    ->leftJoin('provinces', 'users.provinces_id', '=', 'provinces.id')
                    ->leftJoin('cities', 'users.cities_id', '=', 'cities.id')
                    ->leftJoin('type_pets', 'pets.typePet_id', '=', 'type_pets.id')
                    ->leftJoin('status_pets', 'pets.statusPet_id', '=', 'status_pets.id')
                    ->where('pets.name', 'LIKE', '%' . $search . '%')
                    ->orWhere('pets.id', 'LIKE', '%' . $search . '%')
                    ->select('pets.id', 'pets.name', 'pets.breed', 'type_pets.type', 'pets.image', 'provinces.province', 'cities.city', 'status_pets.status')
                    ->orderBy($field, $direction)
                    ->simplePaginate(12);

            } else {
                $pets = DB::table('pets')
                    ->leftJoin('users', 'pets.user_id', '=', 'users.id')
                    ->leftJoin('provinces', 'users.provinces_id', '=', 'provinces.id')
                    ->leftJoin('cities', 'users.cities_id', '=', 'cities.id')
                    ->leftJoin('type_pets', 'pets.typePet_id', '=', 'type_pets.id')
                    ->leftJoin('status_pets', 'pets.statusPet_id', '=', 'status_pets.id')
                    ->where('pets.typePet_id', '=', $especieFilter[0]->id)
                    ->where('pets.statusPet_id', '=', $status_id[0]->id)
                    ->where('pets.name', 'LIKE', '%' . $search . '%')
                    ->orWhere('pets.id', 'LIKE', '%' . $search . '%')
                    ->select('pets.id', 'pets.name', 'pets.breed', 'type_pets.type', 'pets.image', 'provinces.province', 'cities.city', 'status_pets.status')
                    ->orderBy($field, $direction)
                    ->simplePaginate(12);
            }
        }

        return view('admin.pets.pets', array(
            'pets' => $pets,
            'typesPets' => $typesPet,
            'statusPets' => $statusPets,
            'especie' => $especie,
            'order' => $order,
            'status_slug' => $status_slug,
            'search' => $search
        ));
    }

    //Mètode per eliminar una mascota
    public function deletePet($pet_id){
        $pet = Pet::find($pet_id);

        if (Auth::user()->hasRole('admin')) {
            $pet->delete();
            Notification::success('Mascota eliminada correctament.');
        } else {
            Notification::success("La mascota no s'ha pogut eliminar correctament.");
        }

        return redirect()->route('getPets');
    }

    //Mètode per mostrar la pàgina d'editar una mascota
    public function editPet($pet_id){
        $pet = Pet::find($pet_id);
        $typesPet = TypePet::all();
        $statusPets = StatusPet::all();

        if (Auth::user()->hasRole('admin')) {
            return view('admin.pets.editPet', array(
                'statusPets' => $statusPets,
                'typesPet' => $typesPet,
                'pet' => $pet,
            ));
        } else {
            return redirect()->route('home');
        }
    }

    //Mètode per actualitzar una mascota
    public function updatePet($pet_id, Request $request){
        //Validar formulari
        $validateData = $this->validate($request, [
            'name' => 'required|string|max:20',
            'typePet' => 'required',
            'breed' => 'required|string|max:20',
            'birthday' => 'required',
            'gender' => 'required|string|max:20',
            'size' => 'required|string|max:20',
            'weight' => 'numeric|required',
            'statusPet' => 'required',
            'editordata' => 'required',
            'image' => 'mimes:jpeg,png,bmp'
        ]);

        $pet = Pet::find($pet_id);
        $typePet_Slug = $request->input('typePet');
        $typePet = DB::table('type_pets')
            ->where('slug', $typePet_Slug)->get();
        $statusPet_Slug = $request->input('statusPet');
        $statusPet = DB::table('status_pets')
            ->where('slug', $statusPet_Slug)->get();
        $gender = $request->input('gender');

        if ($gender == 'mascle') {
            $gender = 'Mascle';
        } else {
            $gender = 'Femella';
        }

        $pet->name = $request->input('name');
        $pet->slug = str_slug($request->input('name'));
        $pet->typePet_id = $typePet[0]->id;
        $pet->breed = $request->input('breed');
        $pet->birthday = $request->input('birthday');
        $pet->gender = $gender;
        $pet->size = $request->input('size');
        $pet->weight = $request->input('weight');
        $pet->health = $request->input('health');
        $pet->statusPet_id = $statusPet[0]->id;
        $pet->color = $request->input('color');
        $pet->description = $request->input('editordata');

        //Imatge
        $image = $request->file('image');
        if ($image) {
            $image_path = time() . $image->getClientOriginalName();
            \Storage::disk('images')->put($image_path, \File::get($image));
            $pet->image = $image_path;
        }

        $pet->save();

        Notification::success('Mascota actualitzada correctament.');

        return Redirect::back();
    }
}