<?php

namespace App\Http\Controllers\Admin;

use Illuminate\Http\Request;
use App\Http\Controllers\Controller;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Storage;
use Symfony\Component\HttpFoundation\Response;
use Notification;
use Illuminate\Support\Facades\Auth;
use Debugbar;
use App\Category;
use App\StatusPost;
Use App\Post;

class PostController extends Controller
{
    //Mètode per mostrar la pàgina per crear una entrada
    public function createPost()
    {
        $categories = Category::all();
        $statusPosts = StatusPost::all();

        return view('admin.posts.createPost', array(
            'categories' => $categories,
            'statusPosts' => $statusPosts
        ));
    }

    //Mètode per guardar una entrada
    public function savePost(Request $request){
        //Validar formulari
        $validateData = $this->validate($request, [
            'title' => 'required',
            'category' => 'required',
            'status' => 'required',
            'editordata-excerpt' => 'required',
            'editordata-body' => 'required',
            'image' => 'required|mimes:jpeg,png,bmp'
        ]);

        $status_slug = $request->input('status');
        $status =  DB::table('status_posts')
            ->where('slug', '=', $status_slug)->get();
        $category_slug = $request->input('category');
        $category =  DB::table('categories')
            ->where('name', '=', $category_slug)->get();
        $post = new Post();
        $post->title = $request->input('title');
        $post->slug = str_slug($request->input('title'));
        $post->excerpt = $request->input('editordata-excerpt');
        $post->body = $request->input('editordata-body');
        $post->category_id = $category[0]->id;
        $post->statusPost_id = $status[0]->id;

        //Imatge
        $image = $request->file('image');
        if ($image) {
            $image_path = time() . $image->getClientOriginalName();
            \Storage::disk('images')->put($image_path, \File::get($image));
            $post->image = $image_path;
        }

        $post->save();

        Notification::success('Entrada creada correctament.');

        return back();
    }

    //Mètode per llistar les entrades
    public function getPosts(){
        $posts = Post::simplePaginate(10);

        return view('admin.posts.posts', array(
            'posts' => $posts,
        ));
    }

    //Mètode per mostrar la pàgina d'editar una entrada
    public function editPost($post_id){
        $post = Post::find($post_id);
        $categories = Category::all();
        $statusPosts = StatusPost::all();

        if (Auth::user()->hasRole('admin')) {
            return view('admin.posts.editPost', array(
                'post' => $post,
                'categories' => $categories,
                'statusPosts' => $statusPosts
            ));
        } else {
            return redirect()->route('posts');
        }
    }

    //Mètode per actualitzar una entrada
    public function updatePost($post_id, Request $request){
        //Validar formulari
        $validateData = $this->validate($request, [
            'title' => 'required|string|max:190',
            'category' => 'required',
            'status' => 'required',
            'editordata-body' => 'required',
            'image' => 'mimes:jpeg,png,bmp'
        ]);

        $post = Post::find($post_id);
        $category_slug = $request->input('category');
        $category = DB::table('categories')
            ->where('slug', $category_slug)->first();
        $status_slug = $request->input('status');
        $status = DB::table('status_posts')
            ->where('slug', $status_slug)->first();
        $post->title = $request->input('title');
        $post->slug = str_slug($request->input('title'));
        $post->category_id = $category->id;
        $post->statusPost_id= $status->id;
        $post->excerpt = $request->input('editordata-excerpt');
        $post->body = $request->input('editordata-body');

        //Imatge
        $image = $request->file('image');
        if ($image) {
            $image_path = time() . $image->getClientOriginalName();
            \Storage::disk('images')->put($image_path, \File::get($image));
            $post->image = $image_path;
        }

        $post->save();

        $posts = Post::simplePaginate(10);

        Notification::success('Entrada actualitzada correctament.');

        return redirect()->route('getPosts', ['posts' => $posts]);
    }

    //Mètode per eliminar una entrada
    public function deletePost($post_id){
        $post = Post::find($post_id);

        if (Auth::user()->hasRole('admin')) {
            $post->delete();
            Notification::success('Entrada eliminada correctament.');
        } else {
            Notification::success("L'entrada no s'ha pogut eliminar correctament.");
        }

        return redirect()->route('getPosts');
    }

    //Mètode per cercar una entrada
    public function searchAdminPost($search = null){
        if(is_null($search)){
            $search = \Request::get('search');
        }

        $posts = Post::where('title', 'LIKE', '%'.$search.'%')
            ->leftJoin('categories', 'posts.category_id', '=', 'categories.id')
            ->where('statusPost_id', '=', '1')
            ->select('posts.id', 'posts.title','posts.excerpt','categories.name','posts.image', 'posts.created_at', 'categories.id as category_id')
            ->orderBy('id', 'desc')
            ->simplePaginate(12);

        $categories = Category::all();

        $postsSidebar = DB::table('posts')
            ->where('statusPost_id', '=', '1')
            ->orderBy('id', 'desc')
            ->simplePaginate(3);

        return view('admin.posts.search', array(
            'postsSidebar' => $postsSidebar,
            'posts' => $posts,
            'categories' => $categories,
            'search' => $search
        ));
    }

}
