<?php

namespace App\Http\Controllers\Admin;

use Illuminate\Http\Request;
use App\Http\Controllers\Controller;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Auth;
use Notification;
use App\Province;
use App\User;
use App\Pet;
use App\Phone;
use App\City;

class UserController extends Controller
{

    //Mètode per mostrar la pàgina per crear una protectora
    public function createUser(){
        $provinces = Province::all();

        return view('admin.users.createUser', array(
            'provinces' => $provinces,
        ));
    }

    //Mètode per guardar la protectora
    public function saveUser(Request $request){
        //Validar formulari
        $validateData = $this->validate($request, [
            'name' => 'required|string|max:255',
            'email' => 'required|string|email|max:255|unique:users',
            'password' => 'required|string|min:6|confirmed',
            'street' => 'min:3|max:255|required',
            'buildingNumber' => 'min:1|numeric|required',
            'postalCode' => 'min:1|numeric|required',
            'city' => 'required',
            'province' => 'required',
            'phone1' => 'min:8|required',
            'image' => 'required|mimes:jpeg,png,bmp',
        ]);

        $city_id = $request->input('city');
        $province_slug = $request->input('province');
        $province = DB::table('provinces')
            ->where('slug', $province_slug)
            ->get();
        $user = new User();
        $user->name = $request->input('name');
        $user->slug = str_slug($user->name);
        $user->email = $request->input('email');
        $user->password = bcrypt($request->input('name'));
        $user->street = $request->input('street');
        $user->buildingNumber = $request->input('buildingNumber');
        $user->postalCode = $request->input('postalCode');
        $user->cities_id = $city_id;
        $user->provinces_id = $province[0]->id;
        $user->web = $request->input('web');
        $user->facebook = $request->input('facebook');
        $user->twitter = $request->input('twitter');
        $user->instagram = $request->input('instagram');
        $user->teaming = $request->input('teaming');
        $user->description = $request->input('editordata-description');
        $user->conditions = $request->input('editordata-conditions');
        $user->allowsEmail = $request->input('allowsEmail');
        $user->completeRegister = true;

        //Imatge
        $image = $request->file('image');
        if ($image) {
            $image_path = time() . $image->getClientOriginalName();
            \Storage::disk('images')->put($image_path, \File::get($image));
            $user->image = $image_path;
        }

        $user->save();
        $phone = new Phone();
        $phone->number = $request->input('phone1');
        $phone->user_id = $user->id;
        $phone->description = $request->input('phone1-description');
        $phone->save();

        $phone2 = $request->input('phone2');
        if (isset($phone2) && !empty($phone2)) {
            $phone = new Phone();
            $phone->number = $phone2;
            $phone->user_id = $user->id;
            $phone->description = $request->input('phone2-description');
            $phone->save();
        }
        $phone3 = $request->input('phone3');
        if (isset($phone3) && !empty($phone3)) {
            $phone = new Phone();
            $phone->number = $phone3;
            $phone->user_id = $user->id;
            $phone->description = $request->input('phone3-description');
            $phone->save();
        }
        $phone4 = $request->input('phone4');
        if (isset($phone4) && !empty($phone4)) {
            $phone = new Phone();
            $phone->number = $phone4;
            $phone->user_id = $user->id;
            $phone->description = $request->input('phone4-description');
            $phone->save();
        }
        $phone5 = $request->input('phone5');
        if (isset($phone5) && !empty($phone5)) {
            $phone = new Phone();
            $phone->number = $phone5;
            $phone->user_id = $user->id;
            $phone->description = $request->input('phone5-description');
            $phone->save();
        }

        Notification::success('Usuari completat correctament.');

        return redirect()->route('getUsers');
    }

    //Mètode per mostrar la pàgina d'editar una protectora
    public function editUser($user_id){
        $user = User::find($user_id);
        $phones = DB::table('phones')
            ->where('user_id', '=', $user_id)->get();
        $city = DB::table('cities')
            ->where('id', '=', $user->cities_id)->get();
        $city_id = $city[0]->id;
        $province = DB::table('provinces')
            ->where('id', '=', $user->provinces_id)->get();
        $province_id = $province[0]->id;
        $cities = City::all();
        $provinces = Province::all();

        if (Auth::user()->hasRole('admin') || Auth::user()->id == $user_id) {
            return view('admin.users.editUser', array(
                'user' => $user,
                'phones' => $phones,
                'province_id' => $province_id,
                'city_id' => $city_id,
                'cities' => $cities,
                'provinces' => $provinces
            ));
        } else {
            return redirect()->route('home');
        }
    }

    //Mètode per actualitzar una protectora
    public function updateUser($user_id, Request $request){
        //Validar formulari
        $validateData = $this->validate($request, [
            'name' => 'required|string|max:255',
            'street' => 'min:3|max:255|required',
            'buildingNumber' => 'min:1|numeric|required',
            'postalCode' => 'min:1|numeric|required',
            'city' => 'required',
            'province' => 'required',
            'phone1' => 'min:8|required',
            'image' => 'mimes:jpeg,png,bmp',
        ]);

        $city_slug = $request->input('city');
        $province_slug = $request->input('province');
        $city = DB::table('cities')
            ->where('slug', $city_slug)
            ->get();
        $province = DB::table('provinces')
            ->where('slug', $province_slug)
            ->get();
        $user = User::find($user_id);

        $user->name = $request->input('name');
        $user->slug = str_slug($user->name);
        $user->street = $request->input('street');
        $user->buildingNumber = $request->input('buildingNumber');
        $user->postalCode = $request->input('postalCode');
        $user->cities_id = $city[0]->id;
        $user->provinces_id = $province[0]->id;
        $user->web = $request->input('web');
        $user->facebook = $request->input('facebook');
        $user->twitter = $request->input('twitter');
        $user->instagram = $request->input('instagram');
        $user->teaming = $request->input('teaming');
        $user->description = $request->input('editordata-description');
        $user->conditions = $request->input('editordata-conditions');
        $user->allowsEmail = $request->input('allowsEmail');

        //Imatge
        $image = $request->file('image');
        if ($image) {
            $image_path = time() . $image->getClientOriginalName();
            \Storage::disk('images')->put($image_path, \File::get($image));
            $user->image = $image_path;
        }

        $user->save();
        $phones = Phone::where('user_id', $user_id)->get();

        foreach ($phones as $phone) {
            $phone->delete();
        }

        $phone = new Phone();
        $phone->number = $request->input('phone1');
        $phone->user_id = $user_id;
        $phone->description = $request->input('phone1-description');
        $phone->save();

        $phone2 = $request->input('phone2');
        if (isset($phone2) && !empty($phone2)) {
            $phone = new Phone();
            $phone->number = $phone2;
            $phone->user_id = $user_id;
            $phone->description = $request->input('phone2-description');
            $phone->save();
        }
        $phone3 = $request->input('phone3');
        if (isset($phone3) && !empty($phone3)) {
            $phone = new Phone();
            $phone->number = $phone3;
            $phone->user_id = $user_id;
            $phone->description = $request->input('phone3-description');
            $phone->save();
        }
        $phone4 = $request->input('phone4');
        if (isset($phone4) && !empty($phone4)) {
            $phone = new Phone();
            $phone->number = $phone4;
            $phone->user_id = $user_id;
            $phone->description = $request->input('phone4-description');
            $phone->save();
        }
        $phone5 = $request->input('phone5');
        if (isset($phone5) && !empty($phone5)) {
            $phone = new Phone();
            $phone->number = $phone5;
            $phone->user_id = $user_id;
            $phone->description = $request->input('phone5-description');
            $phone->save();
        }

        Notification::success('Usuari actualitzat correctament.');

        return redirect()->back();
    }

    //Mètode per llistar les protectores
    public function getUsers(Request $request){
        $province = $request->input('provincia');

        if (empty($province)) {
            $province = 'totes';
        } else {
            $provinceFilter = DB::table('provinces')
                ->where('slug', '=', $province)
                ->take(1)
                ->get();
        }

        $order = $request->input('ordenar');
        if (empty($order)) {
            $order = 'mes-recents';
        }

        $field = 'users.id';
        $direction = 'desc';

        if ($order == 'mes-recents') {
            $field = 'users.id';
            $direction = 'desc';
        }
        if ($order == 'mes-antigues') {
            $field = 'users.id';
            $direction = 'asc';
        }
        if ($order == 'a-z') {
            $field = 'users.name';
            $direction = 'asc';
        }
        if ($order == 'z-a') {
            $field = 'users.name';
            $direction = 'desc';
        }

        if ($province == 'totes') {
            $provinceFilter = null;

            $users = DB::table('users')
                ->leftJoin('provinces', 'users.provinces_id', '=', 'provinces.id')
                ->leftJoin('cities', 'users.cities_id', '=', 'cities.id')
                ->where('users.id', '!=', '1')
                ->where('users.id', '!=', '2')
                ->where('users.completeRegister', '=', '1')
                ->select('users.id', 'users.name', 'users.image', 'provinces.province', 'cities.city')
                ->orderBy($field, $direction)
                ->simplePaginate(12);
        } else {
            $users = DB::table('users')
                ->leftJoin('provinces', 'users.provinces_id', '=', 'provinces.id')
                ->leftJoin('cities', 'users.cities_id', '=', 'cities.id')
                ->where('users.provinces_id', '=', $provinceFilter[0]->id)
                ->where('users.id', '!=', '1')
                ->where('users.id', '!=', '2')
                ->where('users.completeRegister', '=', '1')
                ->select('users.id', 'users.name', 'users.image', 'provinces.province', 'cities.city')
                ->orderBy($field, $direction)
                ->simplePaginate(12);
        };

        $provincesSelect = Province::all();
        $postsSidebar = DB::table('posts')
            ->where('statusPost_id', '=', '1')
            ->orderBy('id', 'desc')
            ->take(3)
            ->get();

        return view('admin.users.users', array(
            'users' => $users,
            'postsSidebar' => $postsSidebar,
            'provincesSelect' => $provincesSelect,
            'provinceFilter' => $provinceFilter,
            'order' => $order,

        ));
    }

    //Mètode per eliminar una protectora
    public function deleteUser($user_id){
        $user = User::find($user_id);
        $pets = Pet::where('user_id', $user_id)->get();
        $phones = Phone::where('user_id', $user_id)->get();

        if (Auth::user()->hasRole('admin') || Auth::user()->id == $user->id) {
            if ($user_id > 253) {
                Storage::disk('images')->delete($user->image);
                foreach ($pets as $pet) {
                    Storage::disk('images')->delete($pet->image);
                }
            }
            foreach ($pets as $pet) {
                $pet->delete();
            }
            foreach ($phones as $phone) {
                $phone->delete();
            }
            $user->delete();
            Notification::success('Usuari eliminat correctament.');
        } else {
            Notification::success("L'usuari no s'ha pogut eliminar correctament.");
        }
        return redirect()->route('getUsers');
    }
}

