<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use Debugbar;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\DB;
use Notification;
use App\Pet;
use App\User;
use App\Post;
use App\TypePet;
use App\Province;
use App\Subscriptor;
use Symfony\Component\Debug\Debug;

class HomeController extends Controller
{
    /**
     * Create a new controller instance.
     *
     * @return void
     */
    public function __construct()
    {
        $this->middleware('web');
    }

    /**
     * Mètode per mostrar la pàgina principal
     *
     * @return \Illuminate\Http\Response
     */

    public function index(Request $request){
        $pets = DB::table('pets')
            ->leftJoin('users', 'pets.user_id', '=', 'users.id')
            ->leftJoin('provinces', 'users.provinces_id', '=', 'provinces.id')
            ->leftJoin('cities', 'users.cities_id', '=', 'cities.id')
            ->leftJoin('type_pets', 'pets.typePet_id', '=', 'type_pets.id')
            ->where('pets.statusPet_id', '=', '1')
            ->select('pets.id', 'pets.name', 'pets.breed', 'type_pets.type', 'pets.image', 'users.name as protector_name', 'provinces.province', 'cities.city')
            ->orderBy('pets.id', 'desc')
            ->take(6)
            ->get();

        $users = DB::table('users')
            ->leftJoin('provinces', 'users.provinces_id', '=', 'provinces.id')
            ->leftJoin('cities', 'users.cities_id', '=', 'cities.id')
            ->where('users.completeRegister', '=', '1')
            ->select('users.id', 'users.name', 'users.image', 'provinces.province', 'cities.city')
            ->orderBy('users.id', 'desc')
            ->take(6)
            ->get();

        $postsSidebar = DB::table('posts')
            ->where('statusPost_id', '=', '1')
            ->orderBy('id', 'desc')
            ->take(3)
            ->get();

        $typesPet = TypePet::all();
        $provinces = Province::all();

        return view('home', array(
            'pets' => $pets,
            'users' => $users,
            'postsSidebar' => $postsSidebar,
            'typesPet' => $typesPet,
            'provinces' => $provinces
        ));
    }

    //Mètode per guardar un nou subscriptor
    public function saveSubscriber(Request $request){
        //Validar formulari
        $validateData = $this->validate($request, [
            'email' => 'required|string|email|max:255|unique:users',
        ]);

        $email =$request->input('email');
        $subscriptor = new Subscriptor();
        $subscriptor->email = $email;
        $subscriptor->save();

        Notification::success("Enhorabona, has sigut subscrit a la nostra newsletter");

        return redirect()->route('home');
    }
}
