<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Storage;
use PHPUnit\Util\Type;
use Symfony\Component\Debug\Debug;
use Symfony\Component\HttpFoundation\Response;
use Illuminate\Support\Facades\Auth;
use Notification;
use Debugbar;
use Illuminate\Support\Facades\Redirect;
use App\Pet;
use App\User;
use App\TypePet;
use App\StatusPet;
use App\Province;
use App\City;

class PetController extends Controller
{
    //Mètode per crear una mascota
    public function createPet($user_id){
        $typesPet = TypePet::all();
        $statusPets = StatusPet::all();
        $user = User::find($user_id);

        $postsSidebar = DB::table('posts')
            ->where('statusPost_id', '=', '1')
            ->orderBy('id', 'desc')
            ->take(3)
            ->get();

        return view('pet.createPet', array(
            'statusPets' => $statusPets,
            'typesPet' => $typesPet,
            'postsSidebar' => $postsSidebar,
            'user' => $user,
        ));
    }

    //Mètode per guardar una mascota
    public function savePet(Request $request){
        //Validar formulari
        $validateData = $this->validate($request, [
            'name' => 'required|string|max:20',
            'typePet' => 'required',
            'breed' => 'required|string|max:90',
            'birthday' => 'required',
            'gender' => 'required|string|max:20',
            'size' => 'required|string|max:20',
            'weight' => 'numeric|required',
            'statusPet' => 'required',
            'editordata' => 'required',
            'image' => 'required|mimes:jpeg,png,bmp'
        ]);

        $pet = new Pet();
        $user = \Auth::user();
        $typePet_Slug = $request->input('typePet');
        $typePet = DB::table('type_pets')
            ->where('slug', $typePet_Slug)->get();
        $statusPet_Slug = $request->input('statusPet');
        $statusPet = DB::table('status_pets')
            ->where('slug', $statusPet_Slug)->get();

        $pet->user_id = $user->id;
        $pet->name = $request->input('name');
        $pet->slug = str_slug($request->input('name'));
        $pet->typePet_id = $typePet[0]->id;
        $pet->breed = $request->input('breed');
        $pet->birthday = $request->input('birthday');
        $pet->gender = $request->input('gender');
        $pet->size = $request->input('size');
        $pet->weight = $request->input('weight');
        $pet->health = $request->input('name');
        $pet->statusPet_id = $statusPet[0]->id;
        $pet->color = $request->input('color');
        $pet->description = $request->input('editordata');

        //Imatge
        $image = $request->file('image');
        if ($image) {
            $image_path = time() . $image->getClientOriginalName();
            \Storage::disk('images')->put($image_path, \File::get($image));
            $pet->image = $image_path;
        }

        $pet->save();

        Notification::success('Mascota creada correctament.');

        return redirect()->route('getAllPetsUser', ['user_id' => $user->id]);
    }

    //Mètode per eliminar una mascota
    public function deletePet($pet_id){
        $user = \Auth::user();
        $pet = Pet::find($pet_id);

        if ($user && $pet->user_id == $user->id || Auth::user()->hasRole('admin')) {
            //Condició utilitzada només per a la versió amb dades ficticies
            if ($user->id > 253) {
                Storage::disk('images')->delete($pet->image);
            }
            $pet->delete();
            Notification::success('Mascota eliminada correctament.');
        } else {
            Notification::success("La mascota no s'ha pogut eliminar correctament.");
        }

        return redirect()->route('getAllPetsUser', ['user_id' => $user->id]);
    }

    //Mètode que mostra la pàgina per editar una mascota
    public function editPet($pet_id){
        $user = \Auth::user();
        $pet = Pet::find($pet_id);
        $typesPet = TypePet::all();
        $statusPets = StatusPet::all();

        if (Auth::user()->hasRole('admin') || $user->id == $pet->user_id) {
            return view('pet.editPet', array(
                'statusPets' => $statusPets,
                'typesPet' => $typesPet,
                'pet' => $pet,
            ));
        } else {
            return redirect()->route('home');
        }
    }

    //Mètode que actualitza una mascota
    public function updatePet($pet_id, Request $request){
        //Validar formulari
        $validateData = $this->validate($request, [
            'name' => 'required|string|max:20',
            'typePet' => 'required',
            'breed' => 'required|string|max:90',
            'birthday' => 'required',
            'gender' => 'required|string|max:20',
            'size' => 'required|string|max:20',
            'weight' => 'numeric|required',
            'statusPet' => 'required',
            'editordata' => 'required',
            'image' => 'mimes:jpeg,png,bmp'
        ]);

        $pet = Pet::find($pet_id);
        $typePet_Slug = $request->input('typePet');
        $typePet = DB::table('type_pets')
            ->where('slug', $typePet_Slug)->get();
        $statusPet_Slug = $request->input('statusPet');
        $statusPet = DB::table('status_pets')
            ->where('slug', $statusPet_Slug)->get();

        $gender = $request->input('gender');
        if ($gender == 'mascle') {
            $gender = 'Mascle';
        } else {
            $gender = 'Femella';
        }

        $pet->name = $request->input('name');
        $pet->slug = str_slug($request->input('name'));
        $pet->typePet_id = $typePet[0]->id;
        $pet->breed = $request->input('breed');
        $pet->birthday = $request->input('birthday');
        $pet->gender = $gender;
        $pet->size = $request->input('size');
        $pet->weight = $request->input('weight');
        $pet->health = $request->input('health');
        $pet->statusPet_id = $statusPet[0]->id;
        $pet->color = $request->input('color');
        $pet->description = $request->input('editordata');

        //Imatge
        $image = $request->file('image');
        if ($image) {
            $image_path = time() . $image->getClientOriginalName();
            \Storage::disk('images')->put($image_path, \File::get($image));
            $pet->image = $image_path;
        }

        $pet->save();

        Notification::success('Mascota actualitzada correctament.');

        return Redirect::back();
    }

    //Mètode que mostra la imatge
    public function getImage($filename){
        $file = Storage::disk('images')->get($filename);
        return new Response($file, 200);
    }

    //Mètode que mostra la pàgina de detall d'una mascota
    public function getPetDetail($pet_id){
        $pet = Pet::find($pet_id);
        $user = User::find($pet->user_id);
        $city = City::find($user->cities_id);
        $province = Province::find($user->provinces_id);
        $typePet = TypePet::find($pet->typePet_id);

        $postsSidebar = DB::table('posts')
            ->where('statusPost_id', '=', '1')
            ->orderBy('id', 'desc')
            ->take(3)
            ->get();

        $phones = DB::table('phones')
            ->where('user_id', '=', $user->id)
            ->get();

        return view('pet.detail', array(
            'pet' => $pet,
            'postsSidebar' => $postsSidebar,
            'user' => $user,
            'phones' => $phones,
            'city' => $city,
            'province' => $province,
            'typePet' => $typePet
        ));
    }

    //Mètode que mostra la pàgina de resultats de mascotes
    public function index(Request $request){
        $province = $request->input('provincia');

        if (empty($province)) {
            $province = 'totes';
        } else {
            $provinceFilter = DB::table('provinces')
                ->where('slug', '=', $province)
                ->take(1)
                ->get();
        }

        $order = $request->input('ordenar');
        if (empty($order)) {
            $order = 'mes-recents';
        }

        $field = 'pets.id';
        $direction = 'desc';

        if ($order == 'mes-recents') {
            $field = 'pets.id';
            $direction = 'desc';
        }
        if ($order == 'mes-antigues') {
            $field = 'pets.id';
            $direction = 'asc';
        }
        if ($order == 'a-z') {
            $field = 'pets.name';
            $direction = 'asc';
        }
        if ($order == 'z-a') {
            $field = 'pets.name';
            $direction = 'desc';
        }

        $especie = $request->input('especie');
        if (empty($especie)) {
            $especie = 'totes';
        } else {
            $especieFilter = DB::table('type_pets')
                ->where('slug', '=', $especie)
                ->take(1)
                ->get();
        }

        if ($province == 'totes' && $especie == 'totes') {
            $provinceFilter = null;
            $especieFilter = null;

            $pets = DB::table('pets')
                ->leftJoin('users', 'pets.user_id', '=', 'users.id')
                ->leftJoin('provinces', 'users.provinces_id', '=', 'provinces.id')
                ->leftJoin('cities', 'users.cities_id', '=', 'cities.id')
                ->leftJoin('type_pets', 'pets.typePet_id', '=', 'type_pets.id')
                ->where('pets.statusPet_id', '=', '1')
                ->select('pets.id', 'pets.name', 'pets.breed', 'type_pets.type', 'pets.image', 'users.name as protector_name', 'provinces.province', 'cities.city')
                ->orderBy($field, $direction)
                ->simplePaginate(12);

        } else if ($province == 'totes' && $especie != 'totes') {
            $provinceFilter = null;

            $pets = DB::table('pets')
                ->leftJoin('users', 'pets.user_id', '=', 'users.id')
                ->leftJoin('provinces', 'users.provinces_id', '=', 'provinces.id')
                ->leftJoin('cities', 'users.cities_id', '=', 'cities.id')
                ->leftJoin('type_pets', 'pets.typePet_id', '=', 'type_pets.id')
                ->where('pets.typePet_id', '=', $especieFilter[0]->id)
                ->where('pets.statusPet_id', '=', '1')
                ->select('pets.id', 'pets.name', 'pets.breed', 'type_pets.type', 'pets.image', 'users.name as protector_name', 'provinces.province', 'cities.city')
                ->orderBy($field, $direction)
                ->simplePaginate(12);

        } else if ($province != 'totes' && $especie == 'totes') {
            $especieFilter = null;

            $pets = DB::table('pets')
                ->leftJoin('users', 'pets.user_id', '=', 'users.id')
                ->leftJoin('provinces', 'users.provinces_id', '=', 'provinces.id')
                ->leftJoin('cities', 'users.cities_id', '=', 'cities.id')
                ->leftJoin('type_pets', 'pets.typePet_id', '=', 'type_pets.id')
                ->where('users.provinces_id', '=', $provinceFilter[0]->id)
                ->where('pets.statusPet_id', '=', '1')
                ->select('pets.id', 'pets.name', 'pets.breed', 'type_pets.type', 'pets.image', 'users.name as protector_name', 'provinces.province', 'cities.city')
                ->orderBy($field, $direction)
                ->simplePaginate(12);

        } else {
            $pets = DB::table('pets')
                ->leftJoin('users', 'pets.user_id', '=', 'users.id')
                ->leftJoin('provinces', 'users.provinces_id', '=', 'provinces.id')
                ->leftJoin('cities', 'users.cities_id', '=', 'cities.id')
                ->leftJoin('type_pets', 'pets.typePet_id', '=', 'type_pets.id')
                ->where('pets.typePet_id', '=', $especieFilter[0]->id)
                ->where('users.provinces_id', '=', $provinceFilter[0]->id)
                ->where('pets.statusPet_id', '=', '1')
                ->select('pets.id', 'pets.name', 'pets.breed', 'type_pets.type', 'pets.image', 'users.name as protector_name', 'provinces.province', 'cities.city')
                ->orderBy($field, $direction)
                ->simplePaginate(12);
        };

        $provincesSelect = Province::all();
        $typePets = TypePet::all();
        $postsSidebar = DB::table('posts')
            ->where('statusPost_id', '=', '1')
            ->orderBy('id', 'desc')
            ->take(3)
            ->get();

        return view('pet.index', array(
            'pets' => $pets,
            'postsSidebar' => $postsSidebar,
            'provincesSelect' => $provincesSelect,
            'provinceFilter' => $provinceFilter,
            'order' => $order,
            'typePets' => $typePets,
            'especie' => $especie,
            'especieFilter' => $especieFilter,
        ));
    }

    //Mètode que mostra la pàgina de les mascotes d'un cert usuari
    public function getPetsUser($user_id, Request $request){

        $order = $request->input('ordenar');
        if (empty($order)) {
            $order = 'mes-recents';
        }

        $field = 'pets.id';
        $direction = 'desc';

        if ($order == 'mes-recents') {
            $field = 'pets.id';
            $direction = 'desc';
        }
        if ($order == 'mes-antigues') {
            $field = 'pets.id';
            $direction = 'asc';
        }
        if ($order == 'a-z') {
            $field = 'pets.name';
            $direction = 'asc';
        }
        if ($order == 'z-a') {
            $field = 'pets.name';
            $direction = 'desc';
        }

        $especie = $request->input('especie');
        if (empty($especie)) {
            $especie = 'totes';
        } else {
            $especieFilter = DB::table('type_pets')
                ->where('slug', '=', $especie)
                ->take(1)
                ->get();
        }

        $user = User::find($user_id);
        $typesPet = TypePet::all();

        if ($especie == 'totes') {
            $especieFilter = null;

            $pets = DB::table('pets')
                ->leftJoin('users', 'pets.user_id', '=', 'users.id')
                ->leftJoin('provinces', 'users.provinces_id', '=', 'provinces.id')
                ->leftJoin('cities', 'users.cities_id', '=', 'cities.id')
                ->leftJoin('type_pets', 'pets.typePet_id', '=', 'type_pets.id')
                ->where('pets.statusPet_id', '=', '1')
                ->where('pets.user_id', '=', $user_id)
                ->select('pets.id', 'pets.name', 'pets.breed', 'type_pets.type', 'pets.image', 'provinces.province', 'cities.city')
                ->orderBy($field, $direction)
                ->simplePaginate(12);
        } else {
            $pets = DB::table('pets')
                ->leftJoin('users', 'pets.user_id', '=', 'users.id')
                ->leftJoin('provinces', 'users.provinces_id', '=', 'provinces.id')
                ->leftJoin('cities', 'users.cities_id', '=', 'cities.id')
                ->leftJoin('type_pets', 'pets.typePet_id', '=', 'type_pets.id')
                ->where('pets.typePet_id', '=', $especieFilter[0]->id)
                ->where('pets.statusPet_id', '=', '1')
                ->where('pets.user_id', '=', $user_id)
                ->select('pets.id', 'pets.name', 'pets.breed', 'type_pets.type', 'pets.image', 'provinces.province', 'cities.city')
                ->orderBy($field, $direction)
                ->simplePaginate(12);
        }

        $postsSidebar = DB::table('posts')
            ->where('statusPost_id', '=', '1')
            ->orderBy('id', 'desc')
            ->take(3)
            ->get();

        return view('pet.petsUser', array(
            'user' => $user,
            'postsSidebar' => $postsSidebar,
            'pets' => $pets,
            'typesPets' => $typesPet,
            'especie' => $especie,
            'order' => $order,
        ));
    }

    //Mètode que mostra la pàgina totes les mascotes d'un usuari
    public function getAllPetsUser($user_id, $search = null, Request $request){
        if (is_null($search)) {
            $search = \Request::get('search');
        }

        $order = $request->input('ordenar');
        if (empty($order)) {
            $order = 'mes-recents';
        }

        $field = 'pets.id';
        $direction = 'desc';

        if ($order == 'mes-recents') {
            $field = 'pets.id';
            $direction = 'desc';
        }
        if ($order == 'mes-antigues') {
            $field = 'pets.id';
            $direction = 'asc';
        }
        if ($order == 'a-z') {
            $field = 'pets.name';
            $direction = 'asc';
        }
        if ($order == 'z-a') {
            $field = 'pets.name';
            $direction = 'desc';
        }

        $especie = $request->input('especie');
        if (empty($especie)) {
            $especie = 'totes';
        } else {
            $especieFilter = DB::table('type_pets')
                ->where('slug', '=', $especie)
                ->take(1)
                ->get();
        }

        $status_slug = $request->input('estat');

        if (empty($status_slug)) {
            $status_slug = 'tots';
        } else {
            $status_id = DB::table('status_pets')
                ->where('slug', '=', $status_slug)->get();
        }

        $user = User::find($user_id);
        $typesPet = TypePet::all();
        $statusPets = StatusPet::all();

        if (!isset($search) && empty($search)) {
            Debugbar::addMessage('No hi ha cerca');

            if ($especie == 'totes' && $status_slug != 'tots') {
                $especieFilter = null;

                $pets = DB::table('pets')
                    ->leftJoin('users', 'pets.user_id', '=', 'users.id')
                    ->leftJoin('provinces', 'users.provinces_id', '=', 'provinces.id')
                    ->leftJoin('cities', 'users.cities_id', '=', 'cities.id')
                    ->leftJoin('type_pets', 'pets.typePet_id', '=', 'type_pets.id')
                    ->leftJoin('status_pets', 'pets.statusPet_id', '=', 'status_pets.id')
                    ->where('pets.user_id', '=', $user_id)
                    ->where('pets.statusPet_id', '=', $status_id[0]->id)
                    ->select('pets.id', 'pets.name', 'pets.breed', 'type_pets.type', 'pets.image', 'provinces.province', 'cities.city', 'status_pets.status')
                    ->orderBy($field, $direction)
                    ->simplePaginate(12);

            } else if ($especie != 'totes' && $status_slug == 'tots') {
                $pets = DB::table('pets')
                    ->leftJoin('users', 'pets.user_id', '=', 'users.id')
                    ->leftJoin('provinces', 'users.provinces_id', '=', 'provinces.id')
                    ->leftJoin('cities', 'users.cities_id', '=', 'cities.id')
                    ->leftJoin('type_pets', 'pets.typePet_id', '=', 'type_pets.id')
                    ->leftJoin('status_pets', 'pets.statusPet_id', '=', 'status_pets.id')
                    ->where('pets.typePet_id', '=', $especieFilter[0]->id)
                    ->where('pets.user_id', '=', $user_id)
                    ->select('pets.id', 'pets.name', 'pets.breed', 'type_pets.type', 'pets.image', 'provinces.province', 'cities.city', 'status_pets.status')
                    ->orderBy($field, $direction)
                    ->simplePaginate(12);

            } else if ($especie == 'totes' && $status_slug == 'tots') {
                $especieFilter = null;

                $pets = DB::table('pets')
                    ->leftJoin('users', 'pets.user_id', '=', 'users.id')
                    ->leftJoin('provinces', 'users.provinces_id', '=', 'provinces.id')
                    ->leftJoin('cities', 'users.cities_id', '=', 'cities.id')
                    ->leftJoin('type_pets', 'pets.typePet_id', '=', 'type_pets.id')
                    ->leftJoin('status_pets', 'pets.statusPet_id', '=', 'status_pets.id')
                    ->where('pets.user_id', '=', $user_id)
                    ->select('pets.id', 'pets.name', 'pets.breed', 'type_pets.type', 'pets.image', 'provinces.province', 'cities.city', 'status_pets.status')
                    ->orderBy($field, $direction)
                    ->simplePaginate(12);

            } else {
                $pets = DB::table('pets')
                    ->leftJoin('users', 'pets.user_id', '=', 'users.id')
                    ->leftJoin('provinces', 'users.provinces_id', '=', 'provinces.id')
                    ->leftJoin('cities', 'users.cities_id', '=', 'cities.id')
                    ->leftJoin('type_pets', 'pets.typePet_id', '=', 'type_pets.id')
                    ->leftJoin('status_pets', 'pets.statusPet_id', '=', 'status_pets.id')
                    ->where('pets.typePet_id', '=', $especieFilter[0]->id)
                    ->where('pets.user_id', '=', $user_id)
                    ->where('pets.statusPet_id', '=', $status_id[0]->id)
                    ->select('pets.id', 'pets.name', 'pets.breed', 'type_pets.type', 'pets.image', 'provinces.province', 'cities.city', 'status_pets.status')
                    ->orderBy($field, $direction)
                    ->simplePaginate(12);
            }
        } else {
            if ($especie == 'totes' && $status_slug != 'tots') {
                $especieFilter = null;

                $pets = DB::table('pets')
                    ->leftJoin('users', 'pets.user_id', '=', 'users.id')
                    ->leftJoin('provinces', 'users.provinces_id', '=', 'provinces.id')
                    ->leftJoin('cities', 'users.cities_id', '=', 'cities.id')
                    ->leftJoin('type_pets', 'pets.typePet_id', '=', 'type_pets.id')
                    ->leftJoin('status_pets', 'pets.statusPet_id', '=', 'status_pets.id')
                    ->where('pets.user_id', '=', $user_id)
                    ->where('pets.statusPet_id', '=', $status_id[0]->id)
                    ->where('pets.name', 'LIKE', '%' . $search . '%')
                    ->orWhere('pets.id', 'LIKE', '%' . $search . '%')
                    ->select('pets.id', 'pets.name', 'pets.breed', 'type_pets.type', 'pets.image', 'provinces.province', 'cities.city', 'status_pets.status')
                    ->orderBy($field, $direction)
                    ->simplePaginate(12);

            } else if ($especie != 'totes' && $status_slug == 'tots') {
                $pets = DB::table('pets')
                    ->leftJoin('users', 'pets.user_id', '=', 'users.id')
                    ->leftJoin('provinces', 'users.provinces_id', '=', 'provinces.id')
                    ->leftJoin('cities', 'users.cities_id', '=', 'cities.id')
                    ->leftJoin('type_pets', 'pets.typePet_id', '=', 'type_pets.id')
                    ->leftJoin('status_pets', 'pets.statusPet_id', '=', 'status_pets.id')
                    ->where('pets.typePet_id', '=', $especieFilter[0]->id)
                    ->where('pets.user_id', '=', $user_id)
                    ->where('pets.name', 'LIKE', '%' . $search . '%')
                    ->orWhere('pets.id', 'LIKE', '%' . $search . '%')
                    ->select('pets.id', 'pets.name', 'pets.breed', 'type_pets.type', 'pets.image', 'provinces.province', 'cities.city', 'status_pets.status')
                    ->orderBy($field, $direction)
                    ->simplePaginate(12);

            } else if ($especie == 'totes' && $status_slug == 'tots') {
                $especieFilter = null;

                $pets = DB::table('pets')
                    ->leftJoin('users', 'pets.user_id', '=', 'users.id')
                    ->leftJoin('provinces', 'users.provinces_id', '=', 'provinces.id')
                    ->leftJoin('cities', 'users.cities_id', '=', 'cities.id')
                    ->leftJoin('type_pets', 'pets.typePet_id', '=', 'type_pets.id')
                    ->leftJoin('status_pets', 'pets.statusPet_id', '=', 'status_pets.id')
                    ->where('pets.user_id', '=', $user_id)
                    ->where('pets.name', 'LIKE', '%' . $search . '%')
                    ->orWhere('pets.id', 'LIKE', '%' . $search . '%')
                    ->select('pets.id', 'pets.name', 'pets.breed', 'type_pets.type', 'pets.image', 'provinces.province', 'cities.city', 'status_pets.status')
                    ->orderBy($field, $direction)
                    ->simplePaginate(12);

            } else {
                $pets = DB::table('pets')
                    ->leftJoin('users', 'pets.user_id', '=', 'users.id')
                    ->leftJoin('provinces', 'users.provinces_id', '=', 'provinces.id')
                    ->leftJoin('cities', 'users.cities_id', '=', 'cities.id')
                    ->leftJoin('type_pets', 'pets.typePet_id', '=', 'type_pets.id')
                    ->leftJoin('status_pets', 'pets.statusPet_id', '=', 'status_pets.id')
                    ->where('pets.typePet_id', '=', $especieFilter[0]->id)
                    ->where('pets.user_id', '=', $user_id)
                    ->where('pets.statusPet_id', '=', $status_id[0]->id)
                    ->where('pets.name', 'LIKE', '%' . $search . '%')
                    ->orWhere('pets.id', 'LIKE', '%' . $search . '%')
                    ->select('pets.id', 'pets.name', 'pets.breed', 'type_pets.type', 'pets.image', 'provinces.province', 'cities.city', 'status_pets.status')
                    ->orderBy($field, $direction)
                    ->simplePaginate(12);
            }
        }

        $postsSidebar = DB::table('posts')
            ->where('statusPost_id', '=', '1')
            ->orderBy('id', 'desc')
            ->take(3)
            ->get();

        return view('pet.allPetsUser', array(
            'user' => $user,
            'postsSidebar' => $postsSidebar,
            'pets' => $pets,
            'typesPets' => $typesPet,
            'statusPets' => $statusPets,
            'especie' => $especie,
            'order' => $order,
            'status_slug' => $status_slug,
            'search' => $search
        ));
    }
}
