<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Storage;
use Symfony\Component\HttpFoundation\Response;
use Notification;
use Debugbar;
use App\Post;
use App\Category;
use App\StatusPost;

class PostController extends Controller
{
    //Mètode per mostrar una imatge
    public function getImage($filename){
        $file = Storage::disk('images')->get($filename);
        return new Response($file, 200);
    }

    //Mètode per cercar una entrada
    public function searchPost($search = null){
        if(is_null($search)){
            $search = \Request::get('search');
        }

        $posts = Post::where('title', 'LIKE', '%'.$search.'%')
            ->leftJoin('categories', 'posts.category_id', '=', 'categories.id')
            ->where('statusPost_id', '=', '1')
            ->select('posts.id', 'posts.title','posts.excerpt','categories.name','posts.image', 'posts.created_at', 'categories.id as category_id')
            ->orderBy('id', 'desc')
            ->simplePaginate(12);

        $categories = Category::all();

        $postsSidebar = DB::table('posts')
            ->where('statusPost_id', '=', '1')
            ->orderBy('id', 'desc')
            ->simplePaginate(3);

        return view('post.search', array(
            'postsSidebar' => $postsSidebar,
            'posts' => $posts,
            'categories' => $categories,
            'search' => $search
        ));
    }

    //Mètode per mostrar la pàgina de detall d'una entrada
    public function getPostDetail($post_id)
    {
        $post = Post::find($post_id);
        $category = Category::find($post->category_id);

        $postsSidebar = DB::table('posts')
            ->where('statusPost_id', '=', '1')
            ->orderBy('id', 'desc')
            ->take(3)
            ->get();

        $categories = Category::all();

        return view('post.detail', array(
            'post' => $post,
            'postsSidebar' => $postsSidebar,
            'category' => $category,
            'categories' => $categories

        ));
    }

    //Mètode per mostrar la pàgina de resultat de les entrades
    public function index(){
        $posts = DB::table('posts')
            ->leftJoin('categories', 'posts.category_id', '=', 'categories.id')
            ->where('statusPost_id', '=', '1')
            ->select('posts.id', 'posts.title','posts.excerpt','categories.name','posts.image', 'posts.created_at', 'categories.id as category_id')
            ->orderBy('id', 'desc')
            ->simplePaginate(12);

        $categories = Category::all();

        $postsSidebar = DB::table('posts')
            ->where('statusPost_id', '=', '1')
            ->orderBy('id', 'desc')
            ->simplePaginate(3);

        return view('post.index', array(
            'posts' => $posts,
            'categories' => $categories,
            'postsSidebar' => $postsSidebar,
        ));
    }

    //Mètode per llistar les categories
    public function getCategoryIndex($category_id){
        $category = Category::find($category_id);

        $posts = DB::table('posts')
            ->leftJoin('categories', 'posts.category_id', '=', 'categories.id')
            ->where('category_id', '=', $category_id)
            ->where('statusPost_id', '=', '1')
            ->select('posts.id', 'posts.title','posts.excerpt','categories.name','posts.image', 'posts.created_at')
            ->orderBy('id', 'desc')
            ->simplePaginate(12);

        $categories = Category::all();

        $postsSidebar = DB::table('posts')
            ->where('statusPost_id', '=', '1')
            ->orderBy('id', 'desc')
            ->simplePaginate(3);

        return view('post.category', array(
            'posts' => $posts,
            'category' => $category,
            'categories' => $categories,
            'postsSidebar' => $postsSidebar,
        ));
    }
}
