<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Storage;
use Symfony\Component\HttpFoundation\Response;
use Illuminate\Support\Facades\Auth;
use Notification;
use Debugbar;
use Validator;
use Illuminate\Support\Facades\Hash;
use App\User;
use App\Province;
use App\City;
use App\TypePet;
use App\Pet;
use App\Phone;

class UserController extends Controller
{
    //Mètode per mostrar la pàgina de completar usuari
    public function completeUser(){
        $provinces = Province::all();

        return view('auth.completeProfile', array(
            'provinces' => $provinces,
        ));
    }

    //Mètode per guardar l'usuari
    public function saveUser(Request $request){
        //Validar formulari
        $validateData = $this->validate($request, [
            'street' => 'min:3|max:255|required',
            'buildingNumber' => 'min:1|numeric|required',
            'postalCode' => 'min:1|numeric|required',
            'city' => 'required',
            'province' => 'required',
            'phone1' => 'min:8|required',
            'image' => 'required|mimes:jpeg,png,bmp',
        ]);

        $city_id = $request->input('city');
        $province_slug = $request->input('province');
        $province = DB::table('provinces')
            ->where('slug', $province_slug)
            ->get();

        $user = \Auth::user();
        $user->slug = str_slug($user->name);
        $user->street = $request->input('street');
        $user->buildingNumber = $request->input('buildingNumber');
        $user->postalCode = $request->input('postalCode');
        $user->cities_id = $city_id;
        $user->provinces_id = $province[0]->id;
        $user->web = $request->input('web');
        $user->facebook = $request->input('facebook');
        $user->twitter = $request->input('twitter');
        $user->instagram = $request->input('instagram');
        $user->teaming = $request->input('teaming');
        $user->description = $request->input('editordata-description');
        $user->conditions = $request->input('editordata-conditions');
        $user->allowsEmail = $request->input('allowsEmail');
        $user->completeRegister = true;

        //Imatge
        $image = $request->file('image');
        if ($image) {
            $image_path = time() . $image->getClientOriginalName();
            \Storage::disk('images')->put($image_path, \File::get($image));
            $user->image = $image_path;
        }

        $user->save();
        $phone = new Phone();
        $phone->number = $request->input('phone1');
        $phone->user_id = \Auth::user()->id;
        $phone->description = $request->input('phone1-description');
        $phone->save();

        $phone2 = $request->input('phone2');
        if (isset($phone2) && !empty($phone2)) {
            $phone = new Phone();
            $phone->number = $phone2;
            $phone->user_id = \Auth::user()->id;
            $phone->description = $request->input('phone2-description');
            $phone->save();
        }
        $phone3 = $request->input('phone3');
        if (isset($phone3) && !empty($phone3)) {
            $phone = new Phone();
            $phone->number = $phone3;
            $phone->user_id = \Auth::user()->id;
            $phone->description = $request->input('phone3-description');
            $phone->save();
        }
        $phone4 = $request->input('phone4');
        if (isset($phone4) && !empty($phone4)) {
            $phone = new Phone();
            $phone->number = $phone4;
            $phone->user_id = \Auth::user()->id;
            $phone->description = $request->input('phone4-description');
            $phone->save();
        }
        $phone5 = $request->input('phone5');
        if (isset($phone5) && !empty($phone5)) {
            $phone = new Phone();
            $phone->number = $phone5;
            $phone->user_id = \Auth::user()->id;
            $phone->description = $request->input('phone5-description');
            $phone->save();
        }

        Notification::success('Usuari completat correctament.');

        return redirect()->route('home');
    }

    //Mètode per eliminar l'usuari
    public function deleteUser($user_id){
        $user = User::find($user_id);
        $pets = Pet::where('user_id', $user_id)->get();
        $phones = Phone::where('user_id', $user_id)->get();

        if (Auth::user()->hasRole('admin') || Auth::user()->id == $user->id) {
            if ($user_id > 253) {
                Storage::disk('images')->delete($user->image);
                foreach ($pets as $pet) {
                    Storage::disk('images')->delete($pet->image);
                }
            }
            foreach ($pets as $pet) {
                $pet->delete();
            }
            foreach ($phones as $phone) {
                $phone->delete();
            }
            $user->delete();
            Notification::success('Usuari eliminat correctament.');
        } else {
            Notification::success("L'usuari no s'ha pogut eliminar correctament.");
        }
        return redirect()->route('home');
    }

    //Mètode per mostrar la pàgina d'editar l'usuari
    public function editUser($user_id){
        $user = User::find($user_id);
        $phones = DB::table('phones')
            ->where('user_id', '=', $user_id)->get();
        $city = DB::table('cities')
            ->where('id', '=', $user->cities_id)->get();
        $city_id = $city[0]->id;
        $province = DB::table('provinces')
            ->where('id', '=', $user->provinces_id)->get();
        $province_id = $province[0]->id;
        $cities = City::all();
        $provinces = Province::all();

        if (Auth::user()->hasRole('admin') || Auth::user()->id == $user_id) {
            return view('user.edit', array(
                'user' => $user,
                'phones' => $phones,
                'province_id' => $province_id,
                'city_id' => $city_id,
                'cities' => $cities,
                'provinces' => $provinces
            ));
        } else {
            return redirect()->route('home');
        }
    }

    //Mètode per actualitzar l'usuari
    public function updateUser($user_id, Request $request){
        //Validar formulari
        $validateData = $this->validate($request, [
            'name' => 'required|string|max:255',
            'street' => 'min:3|max:255|required',
            'buildingNumber' => 'min:1|numeric|required',
            'postalCode' => 'min:1|numeric|required',
            'city' => 'required',
            'province' => 'required',
            'phone1' => 'min:8|required',
            'image' => 'mimes:jpeg,png,bmp',
        ]);

        $city_slug = $request->input('city');
        $province_slug = $request->input('province');

        $city = DB::table('cities')
            ->where('slug', $city_slug)
            ->get();
        $province = DB::table('provinces')
            ->where('slug', $province_slug)
            ->get();

        $user = User::find($user_id);

        $user->name = $request->input('name');
        $user->slug = str_slug($user->name);
        $user->street = $request->input('street');
        $user->buildingNumber = $request->input('buildingNumber');
        $user->postalCode = $request->input('postalCode');
        $user->cities_id = $city[0]->id;
        $user->provinces_id = $province[0]->id;
        $user->web = $request->input('web');
        $user->facebook = $request->input('facebook');
        $user->twitter = $request->input('twitter');
        $user->instagram = $request->input('instagram');
        $user->teaming = $request->input('teaming');
        $user->description = $request->input('editordata-description');
        $user->conditions = $request->input('editordata-conditions');
        $user->allowsEmail = $request->input('allowsEmail');

        //Imatge
        $image = $request->file('image');
        if ($image) {
            $image_path = time() . $image->getClientOriginalName();
            \Storage::disk('images')->put($image_path, \File::get($image));
            $user->image = $image_path;
        }

        $user->save();
        $phones = Phone::where('user_id', $user_id)->get();

        foreach ($phones as $phone) {
            $phone->delete();
        }

        $phone = new Phone();
        $phone->number = $request->input('phone1');
        $phone->user_id = $user_id;
        $phone->description = $request->input('phone1-description');
        $phone->save();

        $phone2 = $request->input('phone2');
        if (isset($phone2) && !empty($phone2)) {
            $phone = new Phone();
            $phone->number = $phone2;
            $phone->user_id = $user_id;
            $phone->description = $request->input('phone2-description');
            $phone->save();
        }
        $phone3 = $request->input('phone3');
        if (isset($phone3) && !empty($phone3)) {
            $phone = new Phone();
            $phone->number = $phone3;
            $phone->user_id = $user_id;
            $phone->description = $request->input('phone3-description');
            $phone->save();
        }
        $phone4 = $request->input('phone4');
        if (isset($phone4) && !empty($phone4)) {
            $phone = new Phone();
            $phone->number = $phone4;
            $phone->user_id = $user_id;
            $phone->description = $request->input('phone4-description');
            $phone->save();
        }
        $phone5 = $request->input('phone5');
        if (isset($phone5) && !empty($phone5)) {
            $phone = new Phone();
            $phone->number = $phone5;
            $phone->user_id = $user_id;
            $phone->description = $request->input('phone5-description');
            $phone->save();
        }

        Notification::success('Usuari actualitzat correctament.');

        return redirect()->back();
    }

    //Mètode per mostrar la imatge
    public function getImage($filename)
    {
        $file = Storage::disk('images')->get($filename);
        return new Response($file, 200);
    }

    //Mètode per mostra la pàgina de detall de l'usuari
    public function getUserDetail($user_id){
        $user = DB::table('users')
            ->leftJoin('provinces', 'users.provinces_id', '=', 'provinces.id')
            ->leftJoin('cities', 'users.cities_id', '=', 'cities.id')
            ->where('users.id', '=', $user_id)
            ->select('users.id', 'users.name', 'users.slug', 'users.email', 'users.street', 'users.buildingNumber', 'users.postalCode', 'users.web', 'users.facebook', 'users.twitter', 'users.instagram', 'users.teaming', 'users.description', 'users.conditions', 'users.image', 'provinces.province', 'cities.city')
            ->get();

        $phones = DB::table('phones')
            ->where('user_id', '=', $user_id)
            ->get();

        $postsSidebar = DB::table('posts')
            ->where('statusPost_id', '=', '1')
            ->orderBy('id', 'desc')
            ->take(3)
            ->get();

        $pets = DB::table('pets')
            ->leftJoin('users', 'pets.user_id', '=', 'users.id')
            ->leftJoin('provinces', 'users.provinces_id', '=', 'provinces.id')
            ->leftJoin('cities', 'users.cities_id', '=', 'cities.id')
            ->leftJoin('type_pets', 'pets.typePet_id', '=', 'type_pets.id')
            ->where('pets.statusPet_id', '=', '1')
            ->where('pets.user_id', '=', $user_id)
            ->select('pets.id', 'pets.name', 'pets.breed', 'type_pets.type', 'pets.image', 'provinces.province', 'cities.city')
            ->orderBy('pets.id', 'desc')
            ->simplePaginate(6);

        $pets_total = DB::table('pets')
            ->leftJoin('users', 'pets.user_id', '=', 'users.id')
            ->leftJoin('provinces', 'users.provinces_id', '=', 'provinces.id')
            ->leftJoin('cities', 'users.cities_id', '=', 'cities.id')
            ->leftJoin('type_pets', 'pets.typePet_id', '=', 'type_pets.id')
            ->where('pets.statusPet_id', '=', '1')
            ->where('pets.user_id', '=', $user_id)
            ->select('pets.id', 'pets.name', 'pets.breed', 'type_pets.type', 'pets.image', 'provinces.province', 'cities.city')
            ->orderBy('pets.id', 'desc')
            ->get();

        $users = User::find($user_id);

        return view('user.detail', array(
            'user' => $user,
            'postsSidebar' => $postsSidebar,
            'phones' => $phones,
            'pets' => $pets,
            'pets_total' => $pets_total,
            'users' => $users,
        ));
    }

    //Mètode per mostrar la pàgina de resultats de protectores
    public function index(Request $request){
        $province = $request->input('provincia');

        if (empty($province)) {
            $province = 'totes';
        } else {
            $provinceFilter = DB::table('provinces')
                ->where('slug', '=', $province)
                ->take(1)
                ->get();
        }

        $order = $request->input('ordenar');
        if (empty($order)) {
            $order = 'mes-recents';
        }

        $field = 'users.id';
        $direction = 'desc';

        if ($order == 'mes-recents') {
            $field = 'users.id';
            $direction = 'desc';
        }
        if ($order == 'mes-antigues') {
            $field = 'users.id';
            $direction = 'asc';
        }
        if ($order == 'a-z') {
            $field = 'users.name';
            $direction = 'asc';
        }
        if ($order == 'z-a') {
            $field = 'users.name';
            $direction = 'desc';
        }

        if ($province == 'totes') {
            $provinceFilter = null;

            $users = DB::table('users')
                ->leftJoin('provinces', 'users.provinces_id', '=', 'provinces.id')
                ->leftJoin('cities', 'users.cities_id', '=', 'cities.id')
                ->where('users.id', '!=', '1')
                ->where('users.id', '!=', '2')
                ->where('users.completeRegister', '=', '1')

                ->select('users.id', 'users.name', 'users.image', 'provinces.province', 'cities.city')
                ->orderBy($field, $direction)
                ->simplePaginate(12);

        } else {
            $users = DB::table('users')
                ->leftJoin('provinces', 'users.provinces_id', '=', 'provinces.id')
                ->leftJoin('cities', 'users.cities_id', '=', 'cities.id')
                ->where('users.provinces_id', '=', $provinceFilter[0]->id)
                ->where('users.id', '!=', '1')
                ->where('users.id', '!=', '2')
                ->where('users.completeRegister', '=', '1')
                ->select('users.id', 'users.name', 'users.image', 'provinces.province', 'cities.city')
                ->orderBy($field, $direction)
                ->simplePaginate(12);
        };

        $provincesSelect = Province::all();
        $postsSidebar = DB::table('posts')
            ->where('statusPost_id', '=', '1')
            ->orderBy('id', 'desc')
            ->take(3)
            ->get();

        return view('user.index', array(
            'users' => $users,
            'postsSidebar' => $postsSidebar,
            'provincesSelect' => $provincesSelect,
            'provinceFilter' => $provinceFilter,
            'order' => $order,
        ));
    }

    //Mètode per que mostra la pàgina per canviar la contrasenya
    public function changePassword($user_id){
        $user = User::find($user_id);

        if (Auth::user()->hasRole('admin') || Auth::user()->id == $user_id) {
            return view('user.changePassword', array(
                'user' => $user,
            ));
        } else {
            return redirect()->route('home');
        }
    }

    //Mètode actualitza la contrasenya
    public function updatePassword(Request $request, $user_id) {
        //Validar formulari
        $validateData = $this->validate($request, [
            'current_password' =>  'required|min:6',
            'password' => 'required|min:6|confirmed',
        ]);

        $current_password = $request->input('current_password');
        $password = $request->input('password');
        $user = User::find($user_id);

        if (!Hash::check($current_password, $user->password)) {
            return back()->withErrors('Please specify the good current password');
        }else{
            $user->fill([
                'password' => Hash::make($request->password)
            ])->save();

            Notification::success('Usuari actualitzat correctament.');
        }
        return redirect()->route('detailUser', ['user_id' => $user_id]);
    }

    //Mètode per enviar un correu electrònic
    public function sendMail(Request $request){
        //Validar formulari
        $validateData = $this->validate($request, [
            'name' => 'required|string|max:255',
            'email' => 'required|string|email|max:255|unique:users',
            'phone' => 'min:8|required',
            'message' => 'required'
        ]);

        $name = $request->input('name');
        $email = $request->input('email');
        $phone = $request->input('phone');
        $subject = $request->input('subject');
        $missatge = $request->input('message');
        $email_user = Auth::user()->email;

        $data = array(
            'name' => $name,
            'email' => $email,
            'phone' => $phone,
            'subject' => $subject,
            'missatge' => $missatge,

        );
        \Mail::send('emails.contact', $data, function ($message) use ($name, $subject, $email_user){
            $message->from('adopta.una.mascota.org@gmail.com', $name);
            $message->to($email_user)->subject($subject);
        });

        Notification::success('Correu electrònic enviat correctament.');

        return redirect()->route('home');
    }
}
