@extends('admin.layouts.backend')

@section('title', 'Editar entrada · Adopta una mascota')

@section('breadcrumbs')
    <div class="container-fluid">
        <div class="row">
            <div class="col-12">
                {{ Breadcrumbs::render('editPost', $post) }}
            </div>
        </div>
    </div>
@endsection

@section('content')
    <div class="container-fluid">
        <div class="row mt-5 mb-5">
            <div class="col">
                <h1>Editar entrada</h1>
                <form action="{{ route('updatePost', ['post_id' => $post->id]) }}" method="post" enctype="multipart/form-data">
                    {!! csrf_field() !!}
                    @if($errors->any())
                        <div class="alert alert-danger">
                            <ul>
                                @foreach($errors->all() as $error)
                                    <li>{{$error}}</li>
                                @endforeach
                            </ul>
                        </div>
                    @endif
                    <div class="form-group{{ $errors->has('title') ? ' has-error' : '' }}">
                        <label for="title" class="control-label">Títol *</label>

                            <input id="title" type="text" class="form-control" name="title" value="{{ $post->title }}"
                                   required autofocus>

                            @if ($errors->has('title'))
                                <span class="help-block">
                                        <strong>{{ $errors->first('title') }}</strong>
                                    </span>
                            @endif
                    </div>
                    <div class="form-group{{ $errors->has('category') ? ' has-error' : '' }}">
                        <label for="category" class="control-label">Categoria *</label>

                            <select class="custom-select form-control" name="category" required>
                                <option value="null">Selecciona la categoria de l'entrada</option>
                                @foreach($categories as $category)
                                    <option value="{{$category->slug}}" @if($post->category_id == $category->id) selected @endif>{{$category->name}}</option>

                                @endforeach
                            </select>
                            @if ($errors->has('category'))
                                <span class="help-block">
                                        <strong>{{ $errors->first('category') }}</strong>
                                    </span>
                            @endif
                    </div>
                    <div class="form-group{{ $errors->has('status') ? ' has-error' : '' }}">
                        <label for="status" class="control-label">Estat *</label>

                            <select required class="custom-select form-control" name="status" >
                                <option value="null">Selecciona l'estat de l'entrada</option>
                                @foreach($statusPosts as $statusPost)
                                    <option value="{{$statusPost->slug}}" @if($post->statusPost_id == $statusPost->id) selected @endif>{{$statusPost->name}}</option>

                                @endforeach
                            </select>
                            @if ($errors->has('status'))
                                <span class="help-block">
                                        <strong>{{ $errors->first('status') }}</strong>
                                    </span>
                            @endif
                    </div>
                    <div class="form-group{{ $errors->has('editordata-excerpt') ? ' has-error' : '' }}">
                        <label for="editordata-excerpt" class="control-label">Resum</label>

                            <textarea id="editordata-excerpt" type="text" class="form-control"
                                      name="editordata-excerpt">{{ $post->excerpt }}</textarea>

                            @if ($errors->has('editordata-excerpt'))
                                <span class="help-block">
                                        <strong>{{ $errors->first('editordata-excerpt') }}</strong>
                                    </span>
                            @endif
                    </div>
                    <div class="form-group{{ $errors->has('editordata-body') ? ' has-error' : '' }}" required>
                        <label for="editordata-body" class="control-label">Cos *</label>

                            <textarea id="summernote" type="text" class="form-control"
                                      name="editordata-body">{{ $post->body }}</textarea>

                            @if ($errors->has('editordata-body'))
                                <span class="help-block">
                                        <strong>{{ $errors->first('editordata-body') }}</strong>
                                    </span>
                            @endif
                    </div>
                    <div class="form-group upload-file">
                        <label for="image" class="control-label">Imatge *</label>
                        <div class="row">
                            <div class="col-md-12 col-lg-4"><img class="img-fluid"
                                                                 src="{{ url('/imatge/'.$post->image)}}">

                            </div>

                            <div class="col-md-12 col-lg-8">
                                <input type="file" class="form-control" id="image" name="image"
                                       value="{{ old('image') }}">
                            </div>
                        </div>
                    </div>
                    <div class="form-group">
                        <button type="submit" class="button-primary">Actualitzar entrada</button>
                    </div>
                </form>
            </div>
        </div>
    </div>
@endsection

@section('scripts')
    <script>
        $(document).ready(function () {
            $('#summernote').summernote({
                height:200,
                toolbar: [
                    // [groupName, [list of button]]
                    ['style', ['bold', 'italic', 'underline', 'clear']],
                    ['font', ['strikethrough', 'superscript', 'subscript']],
                    ['fontsize', ['fontsize']],
                    ['color', ['color']],
                    ['para', ['ul', 'ol', 'paragraph']],
                    ['height', ['height']]
                ]
            });
        });
    </script>
@endsection