@extends('admin.layouts.backend')

@section('title', $user->name.' · Adopta una mascota')

@section('breadcrumbs')
    <div class="container-fluid">
        <div class="row">
            <div class="col-12">
                {{ Breadcrumbs::render('editAdminUser', $user) }}
            </div>
        </div>
    </div>
@endsection

@section('content')
    <div class="container-fluid">
        <div class="row mb-5 mt-5">
            <div class="col-md-12">
                <h1>Editar protectora</h1>
                <form action="{{ route('updateUser', ['user_id' => $user->id]) }}" method="post"
                      enctype="multipart/form-data">
                    {!! csrf_field() !!}
                    @if($errors->any())
                        <div class="alert alert-danger">
                            <ul>
                                @foreach($errors->all() as $error)
                                    <li>{{$error}}</li>
                                @endforeach
                            </ul>
                        </div>
                    @endif
                    <div class="row">
                        <div class="col-md-6">
                            <div class="form-group{{ $errors->has('name') ? ' has-error' : '' }}">
                                <label for="name" class="control-label">Nom *</label>

                                <input id="name" type="text" class="form-control" name="name"
                                       value="{{ $user->name }}"
                                       maxlength="255" required autofocus>

                                @if ($errors->has('name'))
                                    <span class="help-block"><strong>{{ $errors->first('name') }}</strong></span>
                                @endif
                            </div>
                            <div class="form-group{{ $errors->has('email') ? ' has-error' : '' }}">
                                <label for="email" class="control-label">Adreça electrònica *</label>


                                <input id="email" type="email" class="form-control" name="email"
                                       value="{{ $user->email }}"
                                       required disabled>

                                @if ($errors->has('email'))
                                    <span class="help-block"><strong>{{ $errors->first('email') }}</strong></span>
                                @endif
                            </div>
                            <div class="row">
                                <div class="col-md-8">
                                    <div class="form-group{{ $errors->has('street') ? ' has-error' : '' }}">
                                        <label for="street" class="control-label">Carrer *</label>

                                        <input id="street" type="text" class="form-control" name="street"
                                               minlength="3"
                                               maxlength="255"
                                               value="{{ $user->street }}"
                                               required>

                                        @if ($errors->has('street'))
                                            <span class="help-block"><strong>{{ $errors->first('street') }}</strong></span>
                                        @endif
                                    </div>
                                </div>
                                <div class="col-md-4">
                                    <div class="form-group{{ $errors->has('buildingNumber') ? ' has-error' : '' }}">
                                        <label for="buildingNumber" class="control-label">Numero *</label>

                                        <input id="buildingNumber" type="text" class="form-control"
                                               name="buildingNumber"
                                               value="{{ $user->buildingNumber }}" pattern="[0-9]*" minlength="1"
                                               required>

                                        @if ($errors->has('buildingNumber'))
                                            <span class="help-block"><strong>{{ $errors->first('buildingNumber') }}</strong></span>
                                        @endif
                                    </div>
                                </div>
                            </div>
                            <div class="row">
                                <div class="col-md-6">
                                    <div class="form-group{{ $errors->has('province') ? ' has-error' : '' }}">
                                        <label for="province" class="control-label">Província *</label>

                                        <select class="custom-select form-control" name="province" id="province"
                                                required>
                                            <option value="">Selecciona una província</option>
                                            @foreach($provinces as $province)
                                                <option value="{{$province->slug}}"
                                                        @if($province->id == $province_id) selected @endif>{{$province->province}}</option>
                                            @endforeach
                                        </select>
                                        @if ($errors->has('province'))
                                            <span class="help-block"><strong>{{ $errors->first('province') }}</strong></span>
                                        @endif
                                    </div>
                                </div>
                                <div class="col-md-6">
                                    <div class="form-group{{ $errors->has('city') ? ' has-error' : '' }}">
                                        <label for="city" class="control-label">Localitat *</label>

                                        <select name="city" id="city" class="custom-select form-control" required>
                                            @foreach($cities as $city)
                                                <option value="{{$city->slug}}"
                                                        @if($city->id == $city_id) selected @endif>{{$city->city}}</option>
                                            @endforeach
                                        </select>
                                        @if ($errors->has('city'))
                                            <span class="help-block"><strong>{{ $errors->first('city') }}</strong></span>
                                        @endif
                                    </div>
                                </div>
                            </div>
                            <div class="form-group{{ $errors->has('postalCode') ? ' has-error' : '' }}">
                                <label for="postalCode" class="control-label">Codi Postal *</label>

                                <input id="postalCode" type="text" class="form-control" name="postalCode"
                                       value="{{ $user->postalCode }}" pattern="[0-9]*" minlength="1" required>

                                @if ($errors->has('postalCode'))<span class="help-block">
                                    <strong>{{ $errors->first('postalCode') }}</strong></span>
                                @endif
                            </div>
                        </div>
                        <div class="col-md-6">
                            @foreach($phones as $phone)
                                <div class="row">
                                    <div class="col-md-6">
                                        <div class="form-group{{ $errors->has('phone'.$loop->iteration.'') ? ' has-error' : '' }}">
                                            <label for="phone{{$loop->iteration}}"
                                                   class="control-label">Telèfon {{$loop->iteration}} *</label>

                                            <input id="phone{{$loop->iteration}}" type="text" class="form-control"
                                                   name="phone{{$loop->iteration}}" value="{{ $phone->number }}"
                                                   minlength="8"
                                                   @if($loop->iteration==1) required @endif>

                                            @if ($errors->has('phone'.$loop->iteration.''))
                                                <span class="help-block"><strong>{{ $errors->first('phone'.$loop->iteration.'') }}</strong></span>
                                            @endif
                                        </div>
                                    </div>
                                    <div class="col-md-6">
                                        <div class="form-group{{ $errors->has('phone'.$loop->iteration.'-description') ? ' has-error' : '' }}">
                                            <label for="phone{{$loop->iteration}}-description" class="control-label">Descripció</label>

                                            <input id="phone{{$loop->iteration}}-description" type="text"
                                                   class="form-control" name="phone{{$loop->iteration}}-description"
                                                   minlength="3" maxlength="255" value="{{ $phone->description }}"
                                                   @if($loop->iteration==1) required @endif>

                                            @if ($errors->has('phone'.$loop->iteration.'-description'))
                                                <span class="help-block"><strong>{{ $errors->first('phone'.$loop->iteration.'-description') }}</strong></span>
                                            @endif
                                        </div>
                                    </div>
                                </div>
                            @endforeach
                            @if(count($phones)==0)
                                <div class="row">
                                    <div class="col-md-6">

                                        <div class="form-group{{ $errors->has('phone1') ? ' has-error' : '' }}">
                                            <label for="phone1" class="control-label">Telèfon 1</label>

                                            <input id="phone1" type="text" class="form-control" name="phone1"
                                                   value="{{ old('phone1') }}" minlength="8">

                                            @if ($errors->has('phone1'))
                                                <span class="help-block"><strong>{{ $errors->first('phone1') }}</strong></span>
                                            @endif
                                        </div>
                                    </div>
                                    <div class="col-md-6">

                                        <div class="form-group{{ $errors->has('phone3-description') ? ' has-error' : '' }}">
                                            <label for="phone3-description" class="control-label">Descripció</label>

                                            <input id="phone3-description" type="text" class="form-control"
                                                   name="phone3-description" value="{{ old('phone3-description') }}"
                                                   minlength="3" maxlength="255">

                                            @if ($errors->has('phone3-description'))
                                                <span class="help-block"><strong>{{ $errors->first('phone3-description') }}</strong></span>
                                            @endif
                                        </div>
                                    </div>
                                </div>
                                <div class="row">
                                    <div class="col-md-6">

                                        <div class="form-group{{ $errors->has('phone2') ? ' has-error' : '' }}">
                                            <label for="phone2" class="control-label">Telèfon 2</label>

                                            <input id="phone2" type="text" class="form-control" name="phone2"
                                                   value="{{ old('phone2') }}" minlength="8">

                                            @if ($errors->has('phone2'))
                                                <span class="help-block"><strong>{{ $errors->first('phone2') }}</strong></span>
                                            @endif
                                        </div>
                                    </div>
                                    <div class="col-md-6">

                                        <div class="form-group{{ $errors->has('phone3-description') ? ' has-error' : '' }}">
                                            <label for="phone3-description" class="control-label">Descripció</label>

                                            <input id="phone3-description" type="text" class="form-control"
                                                   name="phone3-description" value="{{ old('phone3-description') }}"
                                                   minlength="3" maxlength="255">

                                            @if ($errors->has('phone3-description'))
                                                <span class="help-block"><strong>{{ $errors->first('phone3-description') }}</strong></span>
                                            @endif
                                        </div>
                                    </div>
                                </div>
                                <div class="row">
                                    <div class="col-md-6">
                                        <div class="form-group{{ $errors->has('phone3') ? ' has-error' : '' }}">
                                            <label for="phone3" class="control-label">Telèfon 3</label>

                                            <input id="phone3" type="text" class="form-control" name="phone3"
                                                   value="{{ old('phone3') }}" minlength="8">

                                            @if ($errors->has('phone3'))
                                                <span class="help-block"><strong>{{ $errors->first('phone3') }}</strong></span>
                                            @endif
                                        </div>
                                    </div>
                                    <div class="col-md-6">

                                        <div class="form-group{{ $errors->has('phone3-description') ? ' has-error' : '' }}">
                                            <label for="phone3-description" class="control-label">Descripció</label>

                                            <input id="phone3-description" type="text" class="form-control"
                                                   name="phone3-description" value="{{ old('phone3-description') }}"
                                                   minlength="3" maxlength="255">

                                            @if ($errors->has('phone3-description'))
                                                <span class="help-block"><strong>{{ $errors->first('phone3-description') }}</strong></span>
                                            @endif
                                        </div>
                                    </div>
                                </div>
                                <div class="row">
                                    <div class="col-md-6">
                                        <div class="form-group{{ $errors->has('phone4') ? ' has-error' : '' }}">
                                            <label for="phone4" class="control-label">Telèfon 4</label>

                                            <input id="phone4" type="text" class="form-control" name="phone4"
                                                   value="{{ old('phone4') }}" minlength="8">

                                            @if ($errors->has('phone4'))
                                                <span class="help-block"><strong>{{ $errors->first('phone4') }}</strong></span>
                                            @endif
                                        </div>
                                    </div>
                                    <div class="col-md-6">

                                        <div class="form-group{{ $errors->has('phone4-description') ? ' has-error' : '' }}">
                                            <label for="phone4-description" class="control-label">Descripció</label>

                                            <input id="phone4-description" type="text" class="form-control"
                                                   name="phone4-description" value="{{ old('phone4-description') }}"
                                                   minlength="3" maxlength="255">

                                            @if ($errors->has('phone4-description'))
                                                <span class="help-block"><strong>{{ $errors->first('phone4-description') }}</strong></span>
                                            @endif
                                        </div>
                                    </div>
                                </div>
                                <div class="row">
                                    <div class="col-md-6">
                                        <div class="form-group{{ $errors->has('phone5') ? ' has-error' : '' }}">
                                            <label for="phone5" class="control-label">Telèfon 5</label>

                                            <input id="phone5" type="text" class="form-control" name="phone5"
                                                   value="{{ old('phone5') }}" minlength="8">

                                            @if ($errors->has('phone5'))
                                                <span class="help-block"><strong>{{ $errors->first('phone5') }}</strong></span>
                                            @endif
                                        </div>
                                    </div>
                                    <div class="col-md-6">

                                        <div class="form-group{{ $errors->has('phone5-description') ? ' has-error' : '' }}">
                                            <label for="phone5-description" class="control-label">Descripció</label>

                                            <input id="phone5-description" type="text" class="form-control"
                                                   name="phone5-description" value="{{ old('phone5-description') }}"
                                                   minlength="3" maxlength="255">

                                            @if ($errors->has('phone5-description'))
                                                <span class="help-block"><strong>{{ $errors->first('phone5-description') }}</strong></span>
                                            @endif
                                        </div>
                                    </div>
                                </div>
                            @endif
                            @if(count($phones)==1)
                                <div class="row">
                                    <div class="col-md-6">

                                        <div class="form-group{{ $errors->has('phone2') ? ' has-error' : '' }}">
                                            <label for="phone2" class="control-label">Telèfon 2</label>

                                            <input id="phone2" type="text" class="form-control" name="phone2"
                                                   value="{{ old('phone2') }}" minlength="8">

                                            @if ($errors->has('phone2'))
                                                <span class="help-block"><strong>{{ $errors->first('phone2') }}</strong></span>
                                            @endif
                                        </div>
                                    </div>
                                    <div class="col-md-6">

                                        <div class="form-group{{ $errors->has('phone3-description') ? ' has-error' : '' }}">
                                            <label for="phone3-description" class="control-label">Descripció</label>

                                            <input id="phone3-description" type="text" class="form-control"
                                                   name="phone3-description" value="{{ old('phone3-description') }}"
                                                   minlength="3" maxlength="255">

                                            @if ($errors->has('phone3-description'))
                                                <span class="help-block"><strong>{{ $errors->first('phone3-description') }}</strong></span>
                                            @endif
                                        </div>
                                    </div>
                                </div>
                                <div class="row">
                                    <div class="col-md-6">
                                        <div class="form-group{{ $errors->has('phone3') ? ' has-error' : '' }}">
                                            <label for="phone3" class="control-label">Telèfon 3</label>

                                            <input id="phone3" type="text" class="form-control" name="phone3"
                                                   value="{{ old('phone3') }}" minlength="8">

                                            @if ($errors->has('phone3'))
                                                <span class="help-block"><strong>{{ $errors->first('phone3') }}</strong></span>
                                            @endif
                                        </div>
                                    </div>
                                    <div class="col-md-6">

                                        <div class="form-group{{ $errors->has('phone3-description') ? ' has-error' : '' }}">
                                            <label for="phone3-description" class="control-label">Descripció</label>

                                            <input id="phone3-description" type="text" class="form-control"
                                                   name="phone3-description" value="{{ old('phone3-description') }}"
                                                   minlength="3" maxlength="255">

                                            @if ($errors->has('phone3-description'))
                                                <span class="help-block"><strong>{{ $errors->first('phone3-description') }}</strong></span>
                                            @endif
                                        </div>
                                    </div>
                                </div>
                                <div class="row">
                                    <div class="col-md-6">
                                        <div class="form-group{{ $errors->has('phone4') ? ' has-error' : '' }}">
                                            <label for="phone4" class="control-label">Telèfon 4</label>

                                            <input id="phone4" type="text" class="form-control" name="phone4"
                                                   value="{{ old('phone4') }}" minlength="8">

                                            @if ($errors->has('phone4'))
                                                <span class="help-block"><strong>{{ $errors->first('phone4') }}</strong></span>
                                            @endif
                                        </div>
                                    </div>
                                    <div class="col-md-6">

                                        <div class="form-group{{ $errors->has('phone4-description') ? ' has-error' : '' }}">
                                            <label for="phone4-description" class="control-label">Descripció</label>

                                            <input id="phone4-description" type="text" class="form-control"
                                                   name="phone4-description" value="{{ old('phone4-description') }}"
                                                   minlength="3" maxlength="255">

                                            @if ($errors->has('phone4-description'))
                                                <span class="help-block"><strong>{{ $errors->first('phone4-description') }}</strong></span>
                                            @endif
                                        </div>
                                    </div>
                                </div>
                                <div class="row">
                                    <div class="col-md-6">
                                        <div class="form-group{{ $errors->has('phone5') ? ' has-error' : '' }}">
                                            <label for="phone5" class="control-label">Telèfon 5</label>

                                            <input id="phone5" type="text" class="form-control" name="phone5"
                                                   value="{{ old('phone5') }}" minlength="8">

                                            @if ($errors->has('phone5'))
                                                <span class="help-block"><strong>{{ $errors->first('phone5') }}</strong></span>
                                            @endif
                                        </div>
                                    </div>
                                    <div class="col-md-6">

                                        <div class="form-group{{ $errors->has('phone5-description') ? ' has-error' : '' }}">
                                            <label for="phone5-description" class="control-label">Descripció</label>

                                            <input id="phone5-description" type="text" class="form-control"
                                                   name="phone5-description" value="{{ old('phone5-description') }}"
                                                   minlength="3" maxlength="255">

                                            @if ($errors->has('phone5-description'))
                                                <span class="help-block"><strong>{{ $errors->first('phone5-description') }}</strong></span>
                                            @endif
                                        </div>
                                    </div>
                                </div>
                            @endif
                            @if(count($phones)==2)
                                <div class="row">
                                    <div class="col-md-6">
                                        <div class="form-group{{ $errors->has('phone3') ? ' has-error' : '' }}">
                                            <label for="phone3" class="control-label">Telèfon 3</label>

                                            <input id="phone3" type="text" class="form-control" name="phone3"
                                                   value="{{ old('phone3') }}" minlength="8">

                                            @if ($errors->has('phone3'))
                                                <span class="help-block"><strong>{{ $errors->first('phone3') }}</strong></span>
                                            @endif
                                        </div>
                                    </div>
                                    <div class="col-md-6">
                                        <div class="form-group{{ $errors->has('phone3-description') ? ' has-error' : '' }}">
                                            <label for="phone3-description" class="control-label">Descripció</label>

                                            <input id="phone3-description" type="text" class="form-control"
                                                   name="phone3-description" value="{{ old('phone3-description') }}"
                                                   minlength="3" maxlength="255">

                                            @if ($errors->has('phone3-description'))
                                                <span class="help-block"><strong>{{ $errors->first('phone3-description') }}</strong></span>
                                            @endif
                                        </div>
                                    </div>
                                </div>
                                <div class="row">
                                    <div class="col-md-6">
                                        <div class="form-group{{ $errors->has('phone4') ? ' has-error' : '' }}">
                                            <label for="phone4" class="control-label">Telèfon4</label>

                                            <input id="phone4" type="text" class="form-control" name="phone4"
                                                   value="{{ old('phone4') }}" minlength="8">

                                            @if ($errors->has('phone4'))
                                                <span class="help-block"><strong>{{ $errors->first('phone4') }}</strong></span>
                                            @endif
                                        </div>
                                    </div>
                                    <div class="col-md-6">
                                        <div class="form-group{{ $errors->has('phone4-description') ? ' has-error' : '' }}">
                                            <label for="phone4-description" class="control-label">Descripció</label>

                                            <input id="phone4-description" type="text" class="form-control"
                                                   name="phone4-description" value="{{ old('phone4-description') }}"
                                                   minlength="3" maxlength="255">

                                            @if ($errors->has('phone4-description'))<span
                                                    class="help-block"><strong>{{ $errors->first('phone4-description') }}</strong></span>
                                            @endif
                                        </div>
                                    </div>
                                </div>
                                <div class="row">
                                    <div class="col-md-6">
                                        <div class="form-group{{ $errors->has('phone5') ? ' has-error' : '' }}">
                                            <label for="phone5" class="control-label">Telèfon 5</label>

                                            <input id="phone5" type="text" class="form-control" name="phone5"
                                                   value="{{ old('phone5') }}" minlength="8">

                                            @if ($errors->has('phone5'))
                                                <span class="help-block"><strong>{{ $errors->first('phone5') }}</strong></span>
                                            @endif
                                        </div>
                                    </div>
                                    <div class="col-md-6">
                                        <div class="form-group{{ $errors->has('phone5-description') ? ' has-error' : '' }}">
                                            <label for="phone5-description" class="control-label">Descripció</label>

                                            <input id="phone5-description" type="text" class="form-control"
                                                   name="phone5-description" value="{{ old('phone5-description') }}"
                                                   minlength="3" maxlength="255">

                                            @if ($errors->has('phone5-description'))
                                                <span class="help-block"><strong>{{ $errors->first('phone5-description') }}</strong></span>
                                            @endif
                                        </div>
                                    </div>
                                </div>
                            @endif
                            @if(count($phones)==3)
                                <div class="row">
                                    <div class="col-md-6">
                                        <div class="form-group{{ $errors->has('phone4') ? ' has-error' : '' }}">
                                            <label for="phone4" class="control-label">Telèfon 4</label>

                                            <input id="phone4" type="text" class="form-control" name="phone4"
                                                   value="{{ old('phone4') }}" minlength="8">

                                            @if ($errors->has('phone4'))<span
                                                    class="help-block"><strong>{{ $errors->first('phone4') }}</strong></span>
                                            @endif
                                        </div>
                                    </div>
                                    <div class="col-md-6">
                                        <div class="form-group{{ $errors->has('phone4-description') ? ' has-error' : '' }}">
                                            <label for="phone4-description" class="control-label">Descripció</label>

                                            <input id="phone4-description" type="text" class="form-control"
                                                   name="phone4-description" value="{{ old('phone4-description') }}"
                                                   minlength="3" maxlength="255">

                                            @if ($errors->has('phone4-description'))
                                                <span class="help-block"><strong>{{ $errors->first('phone4-description') }}</strong></span>
                                            @endif
                                        </div>
                                    </div>
                                </div>
                                <div class="row">
                                    <div class="col-md-6">
                                        <div class="form-group{{ $errors->has('phone5') ? ' has-error' : '' }}">
                                            <label for="phone5" class="control-label">Telèfon 5</label>

                                            <input id="phone5" type="text" class="form-control" name="phone5"
                                                   value="{{ old('phone5') }}" minlength="8">

                                            @if ($errors->has('phone5'))
                                                <span class="help-block"><strong>{{ $errors->first('phone5') }}</strong></span>
                                            @endif
                                        </div>
                                    </div>
                                    <div class="col-md-6">
                                        <div class="form-group{{ $errors->has('phone5-description') ? ' has-error' : '' }}">
                                            <label for="phone5-description" class="control-label">Descripció</label>

                                            <input id="phone5-description" type="text" class="form-control"
                                                   name="phone5-description" value="{{ old('phone5-description') }}"
                                                   minlength="3" maxlength="255">

                                            @if ($errors->has('phone5-description'))
                                                <span class="help-block"><strong>{{ $errors->first('phone5-description') }}</strong></span>
                                            @endif
                                        </div>
                                    </div>
                                </div>
                            @endif
                            @if(count($phones)==4)
                                <div class="row">
                                    <div class="col-md-6">
                                        <div class="form-group{{ $errors->has('phone5') ? ' has-error' : '' }}">
                                            <label for="phone5" class="control-label">Telèfon 5</label>

                                            <input id="phone5" type="text" class="form-control" name="phone5"
                                                   value="{{ old('phone5') }}" minlength="8">

                                            @if ($errors->has('phone5'))
                                                <span class="help-block"><strong>{{ $errors->first('phone5') }}</strong></span>
                                            @endif
                                        </div>
                                    </div>
                                    <div class="col-md-6">
                                        <div class="form-group{{ $errors->has('phone5-description') ? ' has-error' : '' }}">
                                            <label for="phone5-description" class="control-label">Descripció</label>

                                            <input id="phone5-description" type="text" class="form-control"
                                                   name="phone5-description" value="{{ old('phone5-description') }}"
                                                   minlength="3" maxlength="255">

                                            @if ($errors->has('phone5-description'))<span
                                                    class="help-block"><strong>{{ $errors->first('phone5-description') }}</strong></span>
                                            @endif
                                        </div>
                                    </div>
                                </div>
                            @endif
                        </div>
                    </div>

                    <div class="row">
                        <div class="col-md-6">
                            <div class="form-group{{ $errors->has('web') ? ' has-error' : '' }}">
                                <label for="web" class="control-label">Pàgina web</label>

                                <input id="web" type="text" class="form-control" name="web" value="{{ $user->web }}">

                                @if ($errors->has('web'))
                                    <span class="help-block"><strong>{{ $errors->first('web') }}</strong></span>
                                @endif
                            </div>
                            <div class="form-group{{ $errors->has('facebook') ? ' has-error' : '' }}">
                                <label for="facebook" class="control-label">Facebook</label>

                                <input id="facebook" type="text" class="form-control" name="facebook"
                                       value="{{ $user->facebook }}">

                                @if ($errors->has('facebook'))
                                    <span class="help-block"><strong>{{ $errors->first('facebook') }}</strong></span>
                                @endif
                            </div>
                            <div class="form-group{{ $errors->has('twitter') ? ' has-error' : '' }}">
                                <label for="twitter" class="control-label">Twitter</label>

                                <input id="twitter" type="text" class="form-control" name="twitter"
                                       value="{{ $user->twitter }}">

                                @if ($errors->has('twitter'))
                                    <span class="help-block"><strong>{{ $errors->first('twitter') }}</strong></span>
                                @endif
                            </div>
                            <div class="form-group{{ $errors->has('instagram') ? ' has-error' : '' }}">
                                <label for="instagram" class="control-label">Instagram</label>

                                <input id="instagram" type="text" class="form-control" name="instagram"
                                       value="{{ $user->instagram }}">

                                @if ($errors->has('instagram'))
                                    <span class="help-block"><strong>{{ $errors->first('instagram') }}</strong></span>
                                @endif
                            </div>
                            <div class="form-group{{ $errors->has('teaming') ? ' has-error' : '' }}">
                                <label for="teaming" class="control-label">Teaming</label>

                                <input id="teaming" type="text" class="form-control" name="teaming"
                                       value="{{ $user->teaming }}">

                                @if ($errors->has('teaming'))
                                    <span class="help-block"><strong>{{ $errors->first('teaming') }}</strong>
                                </span>
                                @endif
                            </div>
                        </div>
                        <div class="col-md-6">
                            <div class="form-group{{ $errors->has('editordata-description') ? ' has-error' : '' }}">
                                <label for="editordata-description" class="control-label">Descripció</label>

                                <textarea id="summernote-description" type="text" class="form-control"
                                          name="editordata-description">{{ $user->description }}</textarea>

                                @if ($errors->has('editordata-description'))
                                    <span class="help-block"><strong>{{ $errors->first('editordata-description') }}</strong></span>
                                @endif
                            </div>
                            <div class="form-group{{ $errors->has('editordata-conditions') ? ' has-error' : '' }}">
                                <label for="editordata-conditions" class="control-label">Condicions</label>

                                <textarea id="summernote-conditions" type="text" class="form-control"
                                          name="editordata-conditions">{{ $user->conditions }}</textarea>

                                @if ($errors->has('editordata-conditions'))
                                    <span class="help-block"><strong>{{ $errors->first('editordata-conditions') }}</strong></span>
                                @endif
                            </div>

                            <div class="form-group  upload-file">
                                <label for="image" class="control-label">Imatge *</label>
                                <div class="row">
                                    <div class="col-md-4"><img class="img-fluid"
                                                               src="{{ url('/imatge/'.$user->image)}}">

                                    </div>

                                    <div class="col-md-8">
                                        <input type="file" class="form-control" id="image" name="image"
                                               value="{{ old('image') }}">
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>
                    <div class="form-group">
                        <input type="checkbox" class="form-check-input" id="allowsEmail" name="allowsEmail" value="1"
                               @if($user->allowsEmail == 1) checked @endif>
                        <label class="form-check-label" for="allowsEmail">M’agradaria rebre comunicacions publicitàries
                            per correu electrònic. Puc donar-me de baixa quan vulgui.</label>
                    </div>
                    <button type="submit" class="button-primary">Guardar perfil</button>

                </form>
            </div>
        </div>
    </div>
@endsection

@section('scripts')
    <script type="text/javascript">
        $('#province').on('change', function () {
            var provinceSlug = $(this).val();
            console.log(provinceSlug);
            if (provinceSlug) {
                $.ajax({
                    type: "GET",
                    url: "{{url('/llista-ciutats')}}?province_slug=" + provinceSlug,
                    success: function (res) {
                        if (res) {
                            $("#city").empty();
                            $("#city").append('<option value="">Selecciona una localitat</option>');
                            $.each(res, function (key, value) {
                                $("#city").append('<option value="' + res[key].id + '">' + res[key].city + '</option>');
                            });

                        } else {
                            $("#city").empty();
                        }
                    }
                });
            } else {
                $("#city").empty();
            }
        });
    </script>
    <script>
        $(document).ready(function () {
            $('#summernote-description').summernote({
                lang: 'ca-ES' // default: 'en-US'
            });
        });
        $(document).ready(function () {
            $('#summernote-conditions').summernote({
                toolbar: [
                    // [groupName, [list of button]]
                    ['style', ['bold', 'italic', 'underline', 'clear']],
                    ['font', ['strikethrough', 'superscript', 'subscript']],
                    ['fontsize', ['fontsize']],
                    ['color', ['color']],
                    ['para', ['ul', 'ol', 'paragraph']],
                    ['height', ['height']]
                ]
            });
        });
    </script>
@endsection