@extends('layouts.app')

@section('title', 'Completar perfil · Adopta una mascota')

@section('breadcrumbs')
    <div class="container">
        <div class="row">
            <div class="col-12">
                {{ Breadcrumbs::render('completeRegister') }}
            </div>
        </div>
    </div>
@endsection

@section('content')
    <div class="container">
        <div class="row page mt-5 mb-5">
            <div class="col-md-12">
                <h1>Completar perfil</h1>
                <form action="{{ route('saveUser') }}" method="post" enctype="multipart/form-data">
                    {!! csrf_field() !!}
                    @if($errors->any())
                        <div class="alert alert-danger">
                            <ul>
                                @foreach($errors->all() as $error)
                                    <li>{{$error}}</li>
                                @endforeach
                            </ul>
                        </div>
                    @endif
                    <div class="row">
                        <div class="col-md-6">
                            <div class="form-group{{ $errors->has('street') ? ' has-error' : '' }}">
                                <label for="street" class="control-label">Adreça *</label>

                                <input id="street" type="text" class="form-control" name="street" minlength="3"
                                       maxlength="255"
                                       value="{{ old('street') }}"
                                       required autofocus>

                                @if ($errors->has('street'))
                                    <span class="help-block">
                                        <strong>{{ $errors->first('street') }}</strong>
                                    </span>
                                @endif
                            </div>
                            <div class="form-group{{ $errors->has('buildingNumber') ? ' has-error' : '' }}">
                                <label for="buildingNumber" class="control-label">Numero *</label>

                                <input id="buildingNumber" type="text" class="form-control" name="buildingNumber"
                                       value="{{ old('buildingNumber') }}" pattern="[0-9]*" minlength="1"
                                       required>

                                @if ($errors->has('buildingNumber'))
                                    <span class="help-block">
                                        <strong>{{ $errors->first('buildingNumber') }}</strong>
                                    </span>
                                @endif
                            </div>
                            <div class="row">
                                <div class="col-md-6">
                                    <div class="form-group{{ $errors->has('province') ? ' has-error' : '' }}">
                                        <label for="province" class="control-label">Província *</label>
                                        <select class="custom-select form-control" name="province" id="province"
                                                required>
                                            <option value="">Selecciona una província</option>
                                            @foreach($provinces as $province)
                                                <option value="{{$province->slug}}"
                                                        @if(old('province') == $province->slug)  selected @endif>{{$province->province}}</option>
                                            @endforeach
                                        </select>
                                        @if ($errors->has('province'))
                                            <span class="help-block">
                                        <strong>{{ $errors->first('province') }}</strong>
                                    </span>
                                        @endif
                                    </div>
                                </div>
                                <div class="col-md-6">
                                    <div class="form-group{{ $errors->has('city') ? ' has-error' : '' }}">
                                        <label for="city" class="control-label">Localitat *</label>

                                        <select name="city" id="city" class="custom-select form-control" placeholder=""
                                                required>
                                        </select>
                                        @if ($errors->has('city'))
                                            <span class="help-block">
                                        <strong>{{ $errors->first('city') }}</strong>
                                    </span>
                                        @endif
                                    </div>
                                </div>
                            </div>
                            <div class="form-group{{ $errors->has('postalCode') ? ' has-error' : '' }}">
                                <label for="postalCode" class="control-label">Codi Postal *</label>

                                <input id="postalCode" type="text" class="form-control" name="postalCode"
                                       value="{{ old('postalCode') }}" pattern="[0-9]*" minlength="1"
                                       required>

                                @if ($errors->has('postalCode'))
                                    <span class="help-block">
                                        <strong>{{ $errors->first('postalCode') }}</strong>
                                    </span>
                                @endif
                            </div>
                        </div>
                        <div class="col-md-6">
                            <div class="row">
                                <div class="col-md-6">
                                    <div class="form-group{{ $errors->has('phone1') ? ' has-error' : '' }}">
                                        <label for="phone1" class="control-label">Telèfon 1 *</label>

                                        <input id="phone1" type="text" class="form-control" name="phone1"
                                               value="{{ old('phone1') }}" minlength="8"
                                               required>

                                        @if ($errors->has('phone1'))
                                            <span class="help-block">
                                        <strong>{{ $errors->first('phone1') }}</strong>
                                    </span>
                                        @endif
                                    </div>
                                </div>
                                <div class="col-md-6">

                                    <div class="form-group{{ $errors->has('phone1-description') ? ' has-error' : '' }}">
                                        <label for="phone1-description" class="control-label">Descripció</label>

                                        <input id="phone1-description" type="text" class="form-control"
                                               name="phone1-description" minlength="3" maxlength="255"
                                               value="{{ old('phone1-description') }}"
                                        >

                                        @if ($errors->has('phone1-description'))
                                            <span class="help-block">
                                        <strong>{{ $errors->first('phone1-description') }}</strong>
                                    </span>
                                        @endif
                                    </div>
                                </div>
                            </div>
                            <div class="row">
                                <div class="col-md-6">
                                    <div class="form-group{{ $errors->has('phone2') ? ' has-error' : '' }}">
                                        <label for="phone2" class="control-label">Telèfon 2</label>

                                        <input id="phone2" type="text" class="form-control" name="phone2"
                                               minlength="8"
                                               value="{{ old('phone2') }}"
                                        >

                                        @if ($errors->has('phone2'))
                                            <span class="help-block">
                                        <strong>{{ $errors->first('phone2') }}</strong>
                                    </span>
                                        @endif
                                    </div>
                                </div>
                                <div class="col-md-6">
                                    <div class="form-group{{ $errors->has('phone2-description') ? ' has-error' : '' }}">
                                        <label for="phone2-description" class="control-label">Descripció</label>

                                        <input id="phone2-description" type="text" class="form-control"
                                               name="phone2-description"
                                               value="{{ old('phone2-description') }}"
                                        >

                                        @if ($errors->has('phone1-description'))
                                            <span class="help-block">
                                        <strong>{{ $errors->first('phone1-description') }}</strong>
                                    </span>
                                        @endif
                                    </div>
                                </div>
                            </div>
                            <div class="row">
                                <div class="col-md-6">
                                    <div class="form-group{{ $errors->has('phone3') ? ' has-error' : '' }}">
                                        <label for="phone3" class="control-label">Telèfon 3</label>

                                        <input id="phone3" type="text" class="form-control" name="phone3"
                                               minlength="8"
                                               value="{{ old('phone3') }}"
                                        >

                                        @if ($errors->has('phone3'))
                                            <span class="help-block">
                                        <strong>{{ $errors->first('phone3') }}</strong>
                                    </span>
                                        @endif
                                    </div>
                                </div>
                                <div class="col-md-6">

                                    <div class="form-group{{ $errors->has('phone3-description') ? ' has-error' : '' }}">
                                        <label for="phone3-description" class="control-label">Descripció</label>

                                        <input id="phone3-description" type="text" class="form-control"
                                               name="phone3-description"
                                               value="{{ old('phone3-description') }}"
                                        >

                                        @if ($errors->has('phone1-description'))
                                            <span class="help-block">
                                        <strong>{{ $errors->first('phone1-description') }}</strong>
                                    </span>
                                        @endif
                                    </div>
                                </div>
                            </div>
                            <div class="row">
                                <div class="col-md-6">
                                    <div class="form-group{{ $errors->has('phone4') ? ' has-error' : '' }}">
                                        <label for="phone4" class="control-label">Telèfon 4</label>

                                        <input id="phone4" type="text" class="form-control" name="phone4"
                                               minlength="8"
                                               value="{{ old('phone4') }}"
                                        >

                                        @if ($errors->has('phone4'))
                                            <span class="help-block">
                                        <strong>{{ $errors->first('phone4') }}</strong>
                                    </span>
                                        @endif
                                    </div>
                                </div>
                                <div class="col-md-6">
                                    <div class="form-group{{ $errors->has('phone4-description') ? ' has-error' : '' }}">
                                        <label for="phone4-description"
                                               class="control-label">Descripció</label>

                                        <input id="phone4-description" type="text" class="form-control"
                                               name="phone4-description"
                                               value="{{ old('phone4-description') }}"
                                        >

                                        @if ($errors->has('phone1-description'))
                                            <span class="help-block">
                                        <strong>{{ $errors->first('phone1-description') }}</strong>
                                    </span>
                                        @endif
                                    </div>
                                </div>
                            </div>
                            <div class="row">
                                <div class="col-md-6">
                                    <div class="form-group{{ $errors->has('phone5') ? ' has-error' : '' }}">
                                        <label for="phone5" class="control-label">Telèfon 5</label>

                                        <input id="phone5" type="text" class="form-control"
                                               name="phone5"
                                               minlength="8"
                                               value="{{ old('phone5') }}">

                                        @if ($errors->has('phone5'))
                                            <span class="help-block">
                                        <strong>{{ $errors->first('phone5') }}</strong>
                                    </span>
                                        @endif
                                    </div>
                                </div>
                                <div class="col-md-6">
                                    <div class="form-group{{ $errors->has('phone5-description') ? ' has-error' : '' }}">
                                        <label for="phone5-description"
                                               class="control-label">Descripció</label>

                                        <input id="phone5-description" type="text" class="form-control"
                                               name="phone5-description"
                                               value="{{ old('phone5-description') }}"
                                        >

                                        @if ($errors->has('phone5-description'))
                                            <span class="help-block">
                                        <strong>{{ $errors->first('phone5-description') }}</strong>
                                    </span>
                                        @endif
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>
                    <div class="row">
                        <div class="col-md-6">
                            <div class="form-group{{ $errors->has('web') ? ' has-error' : '' }}">
                                <label for="web" class="control-label">Pàgina web</label>

                                <input id="web" type="text" class="form-control" name="web"
                                       value="{{ old('web') }}">

                                @if ($errors->has('web'))
                                    <span class="help-block">
                                        <strong>{{ $errors->first('web') }}</strong>
                                    </span>
                                @endif
                            </div>
                            <div class="form-group{{ $errors->has('facebook') ? ' has-error' : '' }}">
                                <label for="facebook" class="control-label">Facebook</label>

                                <input id="facebook" type="text" class="form-control" name="facebook"
                                       value="{{ old('facebook') }}">

                                @if ($errors->has('facebook'))
                                    <span class="help-block">
                                        <strong>{{ $errors->first('facebook') }}</strong>
                                    </span>
                                @endif
                            </div>
                            <div class="form-group{{ $errors->has('twitter') ? ' has-error' : '' }}">
                                <label for="twitter" class="control-label">Twitter</label>

                                <input id="twitter" type="text" class="form-control" name="twitter"
                                       value="{{ old('twitter') }}">

                                @if ($errors->has('twitter'))
                                    <span class="help-block">
                                        <strong>{{ $errors->first('twitter') }}</strong>
                                    </span>
                                @endif
                            </div>
                            <div class="form-group{{ $errors->has('instagram') ? ' has-error' : '' }}">
                                <label for="instagram" class="control-label">Instagram</label>

                                <input id="instagram" type="text" class="form-control" name="instagram"
                                       value="{{ old('instagram') }}">

                                @if ($errors->has('instagram'))
                                    <span class="help-block">
                                        <strong>{{ $errors->first('instagram') }}</strong>
                                    </span>
                                @endif
                            </div>
                            <div class="form-group{{ $errors->has('teaming') ? ' has-error' : '' }}">
                                <label for="teaming" class="control-label">Teaming</label>

                                <input id="teaming" type="text" class="form-control" name="teaming"
                                       value="{{ old('teaming') }}">

                                @if ($errors->has('teaming'))
                                    <span class="help-block">
                                        <strong>{{ $errors->first('teaming') }}</strong>
                                    </span>
                                @endif
                            </div>
                        </div>
                        <div class="col-md-6">
                            <div class="form-group{{ $errors->has('editordata-description') ? ' has-error' : '' }}">
                                <label for="editordata-description" class="control-label">Descripció</label>

                                <textarea id="summernote-description" class="form-control" type="text"
                                          name="editordata-description">{{ old('editordata-description') }}</textarea>

                                @if ($errors->has('editordata-description'))
                                    <span class="help-block">
                                        <strong>{{ $errors->first('editordata-description') }}</strong>
                                    </span>
                                @endif
                            </div>

                            <div class="form-group{{ $errors->has('editordata-conditions') ? ' has-error' : '' }}">
                                <label for="editordata-conditions" class="control-label">Condicions</label>

                                <textarea id="summernote-conditions" class="form-control" type="text"
                                          name="editordata-conditions">{{ old('editordata-conditions') }}</textarea>

                                @if ($errors->has('editordata-conditions'))
                                    <span class="help-block">
                                        <strong>{{ $errors->first('editordata-conditions') }}</strong>
                                    </span>
                                @endif
                            </div>
                            <div class="form-group  upload-file">
                                <label for="image" class="control-label">Imatge *</label>
                                <input type="file" class="form-control" id="image" name="image"
                                       value="{{ old('image') }}" required>
                            </div>
                        </div>
                    </div>
                    <div class="row">
                        <div class="col-md-6">
                            <div class="form-group">
                                <input type="checkbox" class="form-check-input" id="privacy" name="privacy"
                                       value="{{ old('privacy') }}" required>
                                <label class="form-check-label" for="privacy">He llegit i accepto la <a class="underline"
                                            href="{{ url('/politica-de-privadesa') }}">política
                                        de privadesa</a>.</label>
                            </div>
                            <div class="form-group">
                                <input type="checkbox" class="form-check-input" id="allowsEmail" name="allowsEmail"
                                       value="1" {{ (! empty(old('allowsEmail')) ? 'checked' : '') }}>
                                <label class="form-check-label" for="allowsEmail">M’agradaria rebre comunicacions
                                    publicitàries per correu
                                    electrònic.
                                    Puc donar-me de baixa quan vulgui.</label>
                            </div>
                            <button type="submit" class="button-primary">Guardar perfil</button>
                        </div>
                    </div>
                </form>
            </div>
        </div>
    </div>
@endsection

@section('scripts')
    <script type="text/javascript">
        $('#province').on('change', function () {
            var provinceSlug = $(this).val();
            console.log(provinceSlug);
            if (provinceSlug) {
                $.ajax({
                    type: "GET",
                    url: "{{url('/llista-ciutats')}}?province_slug=" + provinceSlug,
                    success: function (res) {
                        if (res) {
                            $("#city").empty();
                            $("#city").append('<option value="">Selecciona una localitat</option>');
                            $.each(res, function (key, value) {
                                $("#city").append('<option value="' + res[key].id + '">' + res[key].city + '</option>');
                            });

                        } else {
                            $("#city").empty();
                        }
                    }
                });
            } else {
                $("#city").empty();
            }

        });
    </script>
    <script>
        $(document).ready(function () {
            $('#summernote-description').summernote({
                toolbar: [
                    // [groupName, [list of button]]
                    ['style', ['bold', 'italic', 'underline', 'clear']],
                    ['font', ['strikethrough', 'superscript', 'subscript']],
                    ['fontsize', ['fontsize']],
                    ['color', ['color']],
                    ['para', ['ul', 'ol', 'paragraph']],
                    ['height', ['height']]
                ]
            });
        });
        $(document).ready(function () {
            $('#summernote-conditions').summernote({
                toolbar: [
                    // [groupName, [list of button]]
                    ['style', ['bold', 'italic', 'underline', 'clear']],
                    ['font', ['strikethrough', 'superscript', 'subscript']],
                    ['fontsize', ['fontsize']],
                    ['color', ['color']],
                    ['para', ['ul', 'ol', 'paragraph']],
                    ['height', ['height']]
                ]
            });
        });
    </script>
@endsection
