@extends('layouts.app')

@section('title', $user->name.' · Mascotes · Adopta una mascota')

@section('breadcrumbs')
    <div class="container">
        <div class="row">
            <div class="col-12">
                {{ Breadcrumbs::render('getAllPetsUser', $user) }}
            </div>
        </div>
    </div>
@endsection

@section('content')
    <div class="container">
        <div class="row mt-5">
            <div class="col-md-8 col-lg-9">
                <h1>Les meves mascotes</h1>
                <form class="filter" action="{{ route('getAllPetsUser', ['user_id' => $user->id]) }}" method="get"
                      id="filter"
                      enctype="multipart/form-data">
                    <div class="row">
                        <div class="col-md-12 d-flex justify-content-between mb-5">
                            <div class="form-group">
                                <a href="{{ route('createPet', ['user_id' => $user->id]) }}" class="button-create"><i
                                            class="fas fa-plus"></i> Crear mascota</a>
                            </div>
                            <div class="form-group d-flex justify-content-between">
                                <input type="text" class="form-control input-search" placeholder="Cercar"
                                       name="search"
                                       value="{{ $search }}">

                                <button class="icon-search" type="submit">
                                    <i class="fas fa-search"></i>
                                </button>
                            </div>
                        </div>
                        <div class="col-md-4 col-lg-2">
                            <div class="form-group">
                                <label for="especie">Espècie</label>
                                <select class="custom-select form-control" name="especie" id="especie">
                                    <option value="totes">Totes</option>
                                    @foreach($typesPets as $typePet)
                                        @if(isset($especie))
                                            <option value="{{$typePet->slug}}"
                                                    @if($typePet->slug == $especie)  selected @endif>{{$typePet->type}}</option>
                                        @else
                                            <option value="{{$typePet->slug}}">{{$typePet->type}}</option>
                                        @endif
                                    @endforeach
                                </select>
                            </div>
                        </div>
                        <div class="col-md-4 col-lg-3">
                            <label for="especie">Estat</label>
                            <select class="custom-select form-control" name="estat">
                                <option value="tots">Tots</option>
                                @foreach($statusPets as $statusPet)
                                    @if(isset($status_slug))
                                        <option value="{{$statusPet->slug}}"
                                                @if($statusPet->slug == $status_slug)  selected @endif>{{$statusPet->status}}</option>
                                    @else
                                        <option value="{{$statusPet->slug}}">{{$statusPet->status}}</option>

                                    @endif
                                @endforeach
                            </select>
                        </div>
                        <div class="col-md-4 col-lg-3">
                            <label for="ordenar">Ordenar</label>
                            <select class="custom-select form-control" name="ordenar">
                                <option value="mes-recents" @if($order=='mes-recents')selected @endif>Recents</option>
                                <option value="mes-antigues" @if($order=='mes-antigues')selected @endif>Antigues</option>
                                <option value="a-z" @if($order=='a-z')selected @endif>A-Z</option>
                                <option value="z-a" @if($order=='z-a')selected @endif>Z-A</option>
                            </select>
                        </div>
                        <div class="col-md-6 col-lg-2">
                            <a href="{{ route('getAllPetsUser', ['user_id' => $user->id]) }}"
                               class="button-reset">Reiniciar</a>
                        </div>
                        <div class="col-md-6 col-lg-2">
                            <div class="form-group">
                                <button type="submit" class="button-filter">Aplicar</button>
                            </div>
                        </div>
                    </div>
                </form>
                <div class="table-responsive">
                    <table class="table">
                        <thead>
                        <tr>
                            <th>ID</th>
                            <th>Name</th>
                            <th class="breed-type">Espècie · Raça</th>
                            <th class="status">Estat</th>
                            <th>Accions</th>
                        </tr>
                        </thead>
                        <tbody>
                        @foreach($pets as $pet)
                            <tr>
                                <td>{{ $pet->id }}</td>
                                <td>{{ $pet->name }}</td>
                                <td class="breed-type">{{ $pet->type }} · {{ $pet->breed }}</td>
                                <td class="status">{{ $pet->status }}</td>
                                <td>
                                    <a href="{{ route('detailPet', ['pet_id' => $pet->id]) }}"
                                       class="button-table-view"><i class="fas fa-eye"></i> Veure</a>


                                    <a href="{{ url('/mascota/editar/'.$pet->id) }}"
                                       class="button-table-edit"><i class="fas fa-edit"></i> Editar</a>

                                    <!-- Botón en HTML (lanza el modal en Bootstrap) -->
                                    <a href="#victorModal{{$pet->id}}" role="button"
                                       class="button-table-delete"
                                       data-toggle="modal"><i class="fas fa-trash"></i> Eliminar</a>


                                    <!-- Modal / Ventana / Overlay en HTML -->
                                    <div id="victorModal{{$pet->id}}" class="modal fade">
                                        <div class="modal-dialog">
                                            <div class="modal-content">
                                                <div class="">
                                                    <h4 class="">Estàs segur?</h4>
                                                </div>
                                                <div class="modal-body">
                                                    <p>Segur que volas eliminar aquesta mascota?</p>
                                                    <p class="">
                                                        <small>Si l'esborres, mai podràs recuperar-la.
                                                        </small>
                                                    </p>
                                                </div>
                                                <div class="modal-footer">
                                                    <button type="button" class="button-close"
                                                            data-dismiss="modal">
                                                        <i class="fas fa-times-circle"></i> Tancar
                                                    </button>
                                                    <a href=" {{ url('/mascota/eliminar/'.$pet->id) }}"
                                                       type="button"
                                                       class="button-delete"><i class="fas fa-trash"></i>
                                                        Eliminar</a>
                                                </div>
                                            </div>
                                        </div>
                                    </div>
                                </td>
                            </tr>
                        @endforeach
                        </tbody>
                    </table>
                </div>
                <div class="clearfix"></div>
                <div class="row justify-content-center">{{ $pets->appends(request()->input())->links() }}</div>
            </div>
            @include('layouts.sidebar')
        </div>
    </div>
@endsection
