@extends('layouts.app')

@section('title', 'Crear mascota · Adopta una mascota')

@section('breadcrumbs')
    <div class="container">
        <div class="row">
            <div class="col-12">
                {{ Breadcrumbs::render('createPet', $user) }}
            </div>
        </div>
    </div>
@endsection

@section('content')
    <div class="container">
        <div class="row mb-5 mt-5">
            <div class="col-md-12">
                <h1>Crear mascota</h1>
                <form action="{{ route('savePet') }}" method="post" enctype="multipart/form-data">
                    {!! csrf_field() !!}
                    @if($errors->any())
                        <div class="alert alert-danger">
                            <ul>
                                @foreach($errors->all() as $error)
                                    <li>{{$error}}</li>
                                @endforeach
                            </ul>
                        </div>
                    @endif
                    <div class="row">
                        <div class="col-md-6">
                            <div class="form-group{{ $errors->has('name') ? ' has-error' : '' }}">
                                <label for="name" class="control-label">Nom *</label>

                                <input id="name" type="text" class="form-control" name="name" value="{{ old('name') }}"
                                       maxlength="20" required autofocus>

                                @if ($errors->has('name'))
                                    <span class="help-block">
                                        <strong>{{ $errors->first('name') }}</strong>
                                    </span>
                                @endif
                            </div>
                            <div class="form-group{{ $errors->has('typePet') ? ' has-error' : '' }}">
                                <label for="typePet" class="control-label">Espècie *</label>

                                <select class="custom-select form-control" name="typePet" required>
                                    <option value="null">Selecciona l'espècie de la mascota</option>
                                    @foreach($typesPet as $typePet)
                                        <option value="{{$typePet->slug}}">{{$typePet->type}}</option>

                                    @endforeach
                                </select>
                                @if ($errors->has('typePet'))
                                    <span class="help-block">
                                        <strong>{{ $errors->first('typePet') }}</strong>
                                    </span>
                                @endif
                            </div>
                            <div class="form-group{{ $errors->has('breed') ? ' has-error' : '' }}">
                                <label for="breed" class="control-label">Raça *</label>

                                <input id="breed" type="text" class="form-control" name="breed"
                                       value="{{ old('breed') }}" maxlength="100"
                                       maxlength="20" required>

                                @if ($errors->has('breed'))
                                    <span class="help-block">
                                        <strong>{{ $errors->first('breed') }}</strong>
                                    </span>
                                @endif
                            </div>
                            <div class="form-group{{ $errors->has('gender') ? ' has-error' : '' }}">
                                <label for="gender" class="control-label">Gènere *</label>

                                <select class="custom-select form-control" name="gender">
                                    <option value="null">Selecciona el genère de la mascota</option>
                                    <option value="mascle">Mascle</option>
                                    <option value="femella">Femella</option>

                                </select>

                                @if ($errors->has('gender'))
                                    <span class="help-block">
                                        <strong>{{ $errors->first('gender') }}</strong>
                                    </span>
                                @endif
                            </div>
                            <div class="form-group{{ $errors->has('statusPet') ? ' has-error' : '' }}">
                                <label for="statusPet" class="control-label">Estat *</label>

                                <select class="custom-select form-control" name="statusPet">
                                    <option value="null">Selecciona l'estat de la mascota</option>
                                    @foreach($statusPets as $statusPet)
                                        <option value="{{$statusPet->slug}}">{{$statusPet->status}}</option>
                                    @endforeach
                                </select>
                                @if ($errors->has('statusPet'))
                                    <span class="help-block">
                                        <strong>{{ $errors->first('statusPet') }}</strong>
                                    </span>
                                @endif
                            </div>
                            <div class="form-group  upload-file">
                                <label for="image" class="control-label">Imatge *</label>
                                <input type="file" class="form-control" id="image" name="image"
                                       value="{{ old('image') }}" required>
                            </div>
                        </div>
                        <div class="col-md-6">
                            <div class="form-group{{ $errors->has('birthday') ? ' has-error' : '' }}">
                                <label for="birthday" class="control-label">Data de naixement *</label>

                                <input id="birthday" type="date" class="form-control" name="birthday"
                                       value="{{ old('birthday') }}" required>

                                @if ($errors->has('birthday'))
                                    <span class="help-block">
                                        <strong>{{ $errors->first('birthday') }}</strong>
                                    </span>
                                @endif
                            </div>


                            <div class="form-group{{ $errors->has('size') ? ' has-error' : '' }}">
                                <label for="size" class="control-label">Tamany *</label>

                                <input id="size" type="text" class="form-control" name="size" value="{{ old('size') }}"
                                       maxlength="20"
                                       required>

                                @if ($errors->has('size'))
                                    <span class="help-block">
                                        <strong>{{ $errors->first('size') }}</strong>
                                    </span>
                                @endif
                            </div>
                            <div class="form-group{{ $errors->has('weight') ? ' has-error' : '' }}">
                                <label for="weight" class="control-label">Pes *</label>

                                <input id="weight" type="text" class="form-control" name="weight"
                                       value="{{ old('weight') }}" pattern="[0-9]*"
                                       required>

                                @if ($errors->has('weight'))
                                    <span class="help-block">
                                        <strong>{{ $errors->first('weight') }}</strong>
                                    </span>
                                @endif
                            </div>
                            <div class="form-group{{ $errors->has('health') ? ' has-error' : '' }}">
                                <label for="health" class="control-label">Salut</label>

                                <input id="health" type="text" class="form-control" name="health"
                                       value="{{ old('health') }}"
                                       maxlength="20" required>

                                @if ($errors->has('health'))
                                    <span class="help-block">
                                        <strong>{{ $errors->first('health') }}</strong>
                                    </span>
                                @endif
                            </div>

                            <div class="form-group{{ $errors->has('color') ? ' has-error' : '' }}">
                                <label for="color" class="control-label">Color</label>

                                <input id="color" type="text" class="form-control" name="color"
                                       value="{{ old('color') }}"
                                       maxlength="20" required>

                                @if ($errors->has('color'))
                                    <span class="help-block">
                                        <strong>{{ $errors->first('color') }}</strong>
                                    </span>
                                @endif
                            </div>
                            <div class="form-group{{ $errors->has('editordata') ? ' has-error' : '' }}">
                                <label for="editordata" class="control-label">Descripció</label>

                                <textarea id="summernote" type="text" class="form-control"
                                          name="editordata">{{ old('editordata') }}</textarea>

                                @if ($errors->has('editordata'))
                                    <span class="help-block">
                                        <strong>{{ $errors->first('editordata') }}</strong>
                                    </span>
                                @endif
                            </div>
                        </div>

                        <div class="form-group col-md-6">
                            <button type="submit" class="button-primary">Crear mascota</button>
                        </div>
                    </div>
                </form>
            </div>
        </div>
    </div>
@endsection

@section('scripts')
    <script>
        $(document).ready(function () {
            $('#summernote').summernote({
                toolbar: [
                    // [groupName, [list of button]]
                    ['style', ['bold', 'italic', 'underline', 'clear']],
                    ['font', ['strikethrough', 'superscript', 'subscript']],
                    ['fontsize', ['fontsize']],
                    ['color', ['color']],
                    ['para', ['ul', 'ol', 'paragraph']],
                    ['height', ['height']]
                ]
            });
        });
    </script>
@endsection