@extends('layouts.app')

@section('title', $pet->name.' · Editar · Adopta una mascota')

@section('breadcrumbs')
    <div class="container">
        <div class="row">
            <div class="col-12">
                {{ Breadcrumbs::render('editPet', $pet) }}
            </div>
        </div>
    </div>
@endsection

@section('content')
    <div class="container">
        <div class="row mb-5 mt-5">
            <div class="col-md-12">
                <h1>Editar mascota</h1>
                <form action="{{ route('updatePet', ['pet_id' => $pet->id]) }}" method="post"
                      enctype="multipart/form-data">
                    {!! csrf_field() !!}
                    @if($errors->any())
                        <div class="alert alert-danger">
                            <ul>
                                @foreach($errors->all() as $error)
                                    <li>{{$error}}</li>
                                @endforeach
                            </ul>
                        </div>
                    @endif
                    <div class="row">
                        <div class="col-md-6">
                            <div class="form-group{{ $errors->has('name') ? ' has-error' : '' }}">
                                <label for="name" class="control-label">Nom *</label>

                                <input id="name" type="text" class="form-control" name="name" value="{{ $pet->name }}"
                                       maxlength="20" required autofocus>

                                @if ($errors->has('name'))
                                    <span class="help-block">
                                        <strong>{{ $errors->first('name') }}</strong>
                                    </span>
                                @endif
                            </div>
                            <div class="form-group{{ $errors->has('typePet') ? ' has-error' : '' }}">
                                <label for="typePet" class="control-label">Espècie *</label>

                                <select class="custom-select form-control" name="typePet">
                                    <option value="null">Selecciona l'espècie de la mascota</option>
                                    @foreach($typesPet as $typePet)
                                        <option value="{{$typePet->slug}}"
                                                @if($pet->typePet_id == $typePet->id) selected @endif >{{$typePet->type}}</option>

                                    @endforeach
                                </select>
                                @if ($errors->has('typePet'))
                                    <span class="help-block">
                                        <strong>{{ $errors->first('typePet') }}</strong>
                                    </span>
                                @endif
                            </div>
                            <div class="form-group{{ $errors->has('breed') ? ' has-error' : '' }}">
                                <label for="breed" class="control-label">Raça *</label>

                                <input id="breed" type="text" class="form-control" name="breed"
                                       value="{{ $pet->breed }}"
                                       maxlength="20" required>

                                @if ($errors->has('breed'))
                                    <span class="help-block">
                                        <strong>{{ $errors->first('breed') }}</strong>
                                    </span>
                                @endif
                            </div>
                            <div class="form-group{{ $errors->has('gender') ? ' has-error' : '' }}">
                                <label for="gender" class="control-label">Gènere *</label>

                                <select class="custom-select form-control" name="gender">
                                    <option value="null">Selecciona el genère de la mascota</option>
                                    <option value="mascle" @if($pet->gender == 'Mascle') selected @endif >Mascle
                                    </option>
                                    <option value="femella" @if($pet->gender == 'Femella') selected @endif >Femella
                                    </option>
                                </select>

                                @if ($errors->has('gender'))
                                    <span class="help-block">
                                        <strong>{{ $errors->first('gender') }}</strong>
                                    </span>
                                @endif
                            </div>
                            <div class="form-group{{ $errors->has('statusPet') ? ' has-error' : '' }}">
                                <label for="statusPet" class="control-label">Estat *</label>

                                <select class="custom-select form-control" name="statusPet">
                                    <option value="null">Selecciona l'estat de la mascota</option>
                                    @foreach($statusPets as $statusPet)
                                        <option value="{{$statusPet->slug}}"
                                                @if($pet->statusPet_id == $statusPet->id) selected @endif >{{$statusPet->status}}</option>
                                    @endforeach
                                </select>
                                @if ($errors->has('statusPet'))
                                    <span class="help-block">
                                        <strong>{{ $errors->first('statusPet') }}</strong>
                                    </span>
                                @endif
                            </div>
                            <div class="form-group upload-file">
                                <label for="image" class="control-label">Imatge *</label>
                                <div class="row">
                                    <div class="col-md-12 col-lg-4"><img class="img-fluid"
                                                               src="{{ url('/imatge/'.$pet->image)}}">

                                    </div>

                                    <div class="col-md-12 col-lg-8">
                                        <input type="file" class="form-control" id="image" name="image"
                                               value="{{ old('image') }}">
                                    </div>
                                </div>
                            </div>
                        </div>
                        <div class="col-md-6">
                            <div class="form-group{{ $errors->has('birthday') ? ' has-error' : '' }}">
                                <label for="birthday" class="control-label">Data de naixement *</label>

                                <input id="birthday" type="date" class="form-control" name="birthday"
                                       value="{{ $pet->birthday }}"
                                       required>

                                @if ($errors->has('birthday'))
                                    <span class="help-block">
                                        <strong>{{ $errors->first('birthday') }}</strong>
                                    </span>
                                @endif
                            </div>
                            <div class="form-group{{ $errors->has('size') ? ' has-error' : '' }}">
                                <label for="size" class="control-label">Tamany *</label>

                                <input id="size" type="text" class="form-control" name="size" value="{{ $pet->size }}"
                                       maxlength="20" required>

                                @if ($errors->has('size'))
                                    <span class="help-block">
                                        <strong>{{ $errors->first('size') }}</strong>
                                    </span>
                                @endif
                            </div>
                            <div class="form-group{{ $errors->has('weight') ? ' has-error' : '' }}">
                                <label for="weight" class="control-label">Pes *</label>

                                <input id="weight" type="text" class="form-control" name="weight"
                                       value="{{ $pet->weight }}"
                                       required>

                                @if ($errors->has('weight'))
                                    <span class="help-block">
                                        <strong>{{ $errors->first('weight') }}</strong>
                                    </span>
                                @endif
                            </div>
                            <div class="form-group{{ $errors->has('health') ? ' has-error' : '' }}">
                                <label for="health" class="control-label">Salut</label>

                                <input id="health" type="text" class="form-control" name="health"
                                       value="{{ $pet->health }}"
                                       maxlength="20" required>

                                @if ($errors->has('health'))
                                    <span class="help-block">
                                        <strong>{{ $errors->first('health') }}</strong>
                                    </span>
                                @endif
                            </div>

                            <div class="form-group{{ $errors->has('color') ? ' has-error' : '' }}">
                                <label for="color" class="control-label">Color</label>

                                <input id="color" type="text" class="form-control" name="color"
                                       value="{{ $pet->color }}"
                                       maxlength="20" required>

                                @if ($errors->has('color'))
                                    <span class="help-block">
                                        <strong>{{ $errors->first('color') }}</strong>
                                    </span>
                                @endif
                            </div>
                            <div class="form-group{{ $errors->has('editordata') ? ' has-error' : '' }}">
                                <label for="editordata" class="control-label">Descripció</label>

                                <textarea id="summernote" type="text" class="form-control"
                                          name="editordata">{{ $pet->description }}</textarea>

                                @if ($errors->has('editordata'))
                                    <span class="help-block">
                                        <strong>{{ $errors->first('editordata') }}</strong>
                                    </span>
                                @endif
                            </div>
                        </div>
                        <div class="form-group col-md-6">
                            <button type="submit" class="button-primary">Guardar mascota</button>
                        </div>
                    </div>
                </form>
            </div>
        </div>
    </div>
@endsection
@section('scripts')
    <script>
        $(document).ready(function () {
            $('#summernote').summernote({
                toolbar: [
                    // [groupName, [list of button]]
                    ['style', ['bold', 'italic', 'underline', 'clear']],
                    ['font', ['strikethrough', 'superscript', 'subscript']],
                    ['fontsize', ['fontsize']],
                    ['color', ['color']],
                    ['para', ['ul', 'ol', 'paragraph']],
                    ['height', ['height']]
                ]
            });
        });
    </script>
@endsection