@extends('layouts.app')

@section('title', $user->name.' · Mascotes · Adopta una mascota')

@section('breadcrumbs')
    <div class="container">
        <div class="row">
            <div class="col-12">
                {{ Breadcrumbs::render('petsUser', $user) }}
            </div>
        </div>
    </div>
@endsection

@section('content')
    <div class="container">
        <div class="row mt-5">
            <div class="col-md-8">
                {{-- Si no hi ha tipus de mascota seleccionada...--}}
                @if(!isset($especieFilter) && empty($especieFilter))
                    <h1>@if($especie == 'gos') Gossos @else Gats @endif de {{$user->name}}</h1>
                    {{-- Si no hi ha cap dels dos filtres seleccionats...--}}
                @else
                    <h1>{{$user->name}} de {{$user->name}}</h1>
                @endif
                <form class="filter" action="{{ route('getPetsUser', ['user_id' => $user->id]) }}" method="get"
                      enctype="multipart/form-data">
                    <div class="row">
                        <div class="col-md-4 col-lg-3">
                            <div class="form-group">
                                <label for="especie">Espècie</label>
                                <select class="custom-select form-control" name="especie" id="especie">
                                    <option value="totes">Totes</option>
                                    @foreach($typesPets as $typePet)
                                        @if(isset($especie))
                                            <option value="{{$typePet->slug}}"
                                                    @if($typePet->slug == $especie)  selected @endif>{{$typePet->type}}</option>
                                        @else
                                            <option value="{{$typePet->slug}}">{{$typePet->type}}</option>
                                        @endif
                                    @endforeach
                                </select>
                            </div>
                        </div>
                        <div class="col-md-4 col-lg-3">
                            <label for="ordenar">Ordenar</label>
                            <select class="custom-select form-control" name="ordenar">
                                <option value="mes-recents" @if($order=='mes-recents')selected @endif>Recents</option>
                                <option value="mes-antigues" @if($order=='mes-antigues')selected @endif>Antigues</option>
                                <option value="a-z" @if($order=='a-z')selected @endif>A-Z</option>
                                <option value="z-a" @if($order=='z-a')selected @endif>Z-A</option>
                            </select>
                        </div>
                        <div class="col-md-4 col-md-offset-3 col-lg-3">
                            <div class="form-group">
                                <button type="submit" class="button-filter">Aplicar</button>
                            </div>
                        </div>
                    </div>
                </form>
                <div class="row">
                    <div class="pets-list">
                        @foreach($pets as $pet)
                            <div class="pet-item col-sm-6 col-md-6 col-lg-4 pull-left">
                                @if(Storage::disk('images')->has($pet->image))
                                    <div class="pet-image-thumb">
                                        <div class="pet-image-mask">
                                            <a href="{{ route('detailPet', ['pet_id' => $pet->id]) }}">
                                                <img class="img-responsive" src="{{ url('/imatge/'.$pet->image)}}">
                                            </a>
                                        </div>
                                    </div>
                                @endif
                                <div class="data">
                                    <a href="{{ route('detailPet', ['pet_id' => $pet->id]) }}">
                                        <h3>{{ $pet->name }}</h3>
                                    </a>
                                    <h5>{{ $pet->city }} ({{ $pet->province }})</h5>
                                    <h6>{{ $pet->type }} · {{ $pet->breed }}</h6>
                                </div>
                            </div>
                        @endforeach
                    </div>
                    <div class="clearfix"></div>
                    <div class="row justify-content-center">{{ $pets->appends(request()->input())->links() }}</div>
                </div>
                </div>
                @include('layouts.sidebar')
            </div>
    </div>
@endsection
