<?php

/*
|--------------------------------------------------------------------------
| Web Routes
|--------------------------------------------------------------------------
|
| Here is where you can register web routes for your application. These
| routes are loaded by the RouteServiceProvider within a group which
| contains the "web" middleware group. Now create something great!
|
*/

Route::get('/', function () {return view('home');});
Route::get('/', array('as' => 'home', 'uses' => 'HomeController@index'));
Route::post('/enviar-correu', array('as' => 'sendContact', 'uses' => 'SiteController@sendContact'));
Route::post('/guardar-subscriptor', array('as' => 'saveSubscriber', 'uses' => 'HomeController@saveSubscriber'));
Route::post('/enviar-email', array('as' => 'sendMail', 'uses' => 'SiteController@sendMail'));
Route::post('/enviar-email-protectora', array('as' => 'sendMailUser', 'uses' => 'UserController@sendMail'));

//Rutes del controlador d'Usuaris
Auth::routes();
Route::get('/completar-perfil', array('as' => 'completeUser', 'middleware' => 'auth', 'uses' => 'UserController@completeUser'));
Route::post('/guardar-perfil', array('as' => 'saveUser', 'middleware' => 'auth', 'uses' => 'UserController@saveUser'));
Route::post('/actualitzar-perfil/{user_id}', array('as' => 'updateUser', 'middleware' => 'auth', 'uses' => 'UserController@updateUser'));
Route::get('/modificar-contrasenya/{user_id}', array('as' => 'changePassword', 'middleware' => 'auth', 'uses' => 'UserController@changePassword'));
Route::post('/actualitzar-contrasenya/{user_id}', array('as' => 'updatePassword', 'middleware' => 'auth', 'uses' => 'UserController@updatePassword'));
Route::get('/protectora/{user_id}', array('as' => 'detailUser', 'uses' => 'UserController@getUserDetail'));
Route::get('/protectora/eliminar/{user_id}', array('as' => 'deleteUser', 'uses' => 'UserController@deleteUser'));
Route::get('/protectora/editar/{user_id}', array('as' => 'editUser', 'uses' => 'UserController@editUser'));
Route::get('/protectora/crear-mascota/{user_id}', array('as' => 'createPet', 'middleware' => 'auth', 'uses' => 'PetController@createPet'));
Route::get('/protectores/', array('as' => 'indexUser', 'uses' => 'UserController@index'));
Route::get('/imatge/{filename}', array('as' => 'imageUser', 'uses' => 'UserController@getImage'));

//Rutes del controlador de Mascotes
Route::post('/mascotes/guardar-mascota', array('as' => 'savePet', 'middleware' => 'auth', 'uses' => 'PetController@savePet'));
Route::post('/mascota/actualitzar-mascota/{pet_id}', array('as' => 'updatePet', 'middleware' => 'auth', 'uses' => 'PetController@updatePet'));
Route::get('/mascota/eliminar/{pet_id}', array('as' => 'deletePet', 'middleware' => 'auth', 'uses' => 'PetController@deletePet'));
Route::get('/mascota/editar/{pet_id}', array('as' => 'editPet', 'middleware' => 'auth', 'uses' => 'PetController@editPet'));
Route::get('/mascota/{pet_id}', array('as' => 'detailPet', 'uses' => 'PetController@getPetDetail'));
Route::get('/mascotes', array('as' => 'indexPet', 'uses' => 'PetController@index'));
Route::get('/imatge/{filename}', array('as' => 'imagePet', 'uses' => 'PetController@getImage'));
Route::get('/protectora/{user_id}/les-meves-mascotes', array('as' => 'getAllPetsUser', 'middleware' => 'auth', 'uses' => 'PetController@getAllPetsUser'));
Route::get('/protectora/{user_id}/les-meves-mascotes/{search?}', array('as' => 'searchPet', 'middleware' => 'auth', 'uses' => 'PetController@getAllPetsUser'));
Route::get('/protectora/{user_id}/mascotes', array('as' => 'getPetsUser', 'uses' => 'PetController@getPetsUser'));

//Ruta del controlador per recuperar les ciutats d'una província
Route::get('/llista-ciutats', array('as' => 'getCities', 'uses' => 'CityController@getCitiesList'));

//Rutes del blog
Route::get('/blog/entrada/{post_id}', array('as' => 'detailPost', 'uses' => 'PostController@getPostDetail'));
Route::get('/blog/cerca/{search?}', array('as' => 'searchPost', 'uses' => 'PostController@searchPost'));
Route::get('/blog/', array('as' => 'indexBlog', 'uses' => 'PostController@index'));
Route::get('/blog/categoria/{categoria_id}', array('as' => 'categoryPost', 'uses' => 'PostController@getCategoryIndex'));
Route::get('/imatge/{filename}', array('as' => 'imagePost', 'uses' => 'PostController@getImage'));

//Rutes de les pàgines estàtiques
Route::get('/contacte', array('as' => 'getContactPage', 'uses' => 'SiteController@getContactPage'));
Route::get('/qui-som', array('as' => 'getAboutUsPage', 'uses' => 'SiteController@getAboutUsPage'));
Route::get('/avis-legal', array('as' => 'getLegalPage', 'uses' => 'SiteController@getLegalPage'));
Route::get('/ajuda', array('as' => 'getHelpPage', 'uses' => 'SiteController@getHelpPage'));
Route::get('/preguntes-frequents', array('as' => 'getFaqPage', 'uses' => 'SiteController@getFaqPage'));
Route::get('/politica-de-privadesa', array('as' => 'getPrivacyPage', 'uses' => 'SiteController@getPrivacyPage'));
Route::get('/politica-de-galetes', array('as' => 'getCookiesPage', 'uses' => 'SiteController@getCookiesPage'));

//Rutes de l'administrador
Route::get('/admin/mascotes/', array('as' => 'getPets', 'middleware' => 'admin', 'uses' => 'Admin\PetController@getPets'));
Route::get('/admin/mascotes/{search?}', array('as' => 'searchAdminPets', 'middleware' => 'admin', 'uses' => 'Admin\PetController@getPets'));
Route::get('/admin/borrar-mascota/{pet_id}', array('as' => 'deletePet', 'middleware' => 'admin', 'uses' => 'Admin\PetController@deletePet'));
Route::get('/admin/editar-mascota/{pet_id}', array('as' => 'editAdminPet', 'middleware' => 'admin', 'uses' => 'Admin\PetController@editPet'));
Route::post('/admin/actualitzar-mascota/{pet_id}', array('as' => 'updateAdminPet', 'middleware' => 'admin', 'uses' => 'Admin\PetController@updatePet'));
Route::get('/admin/crear-mascota/{user_id}', array('as' => 'createAdminPet', 'middleware' => 'admin', 'uses' => 'Admin\PetController@createPet'));
Route::post('/admin/guardar-mascota/{user_id}', array('as' => 'saveAdminPet', 'middleware' => 'admin', 'uses' => 'Admin\PetController@savePet'));
Route::get('/admin/crear-protectora/', array('as' => 'createUser', 'middleware' => 'admin', 'uses' => 'Admin\UserController@createUser'));
Route::get('/admin/protectores/', array('as' => 'getUsers', 'middleware' => 'admin', 'uses' => 'Admin\UserController@getUsers'));
Route::post('/admin/guardar-protectora', array('as' => 'saveAdminUser', 'middleware' => 'admin', 'uses' => 'Admin\UserController@saveUser'));
Route::get('/admin/borrar-protectora/{user_id}', array('as' => 'deleteAdminUser', 'middleware' => 'admin', 'uses' => 'Admin\UserController@deleteUser'));
Route::get('/admin/editar-protectora/{user_id}', array('as' => 'editAdminUser', 'middleware' => 'admin', 'uses' => 'Admin\UserController@editUser'));
Route::post('/admin/actualitzar-protectora/{user_id}', array('as' => 'updateAdminUser', 'middleware' => 'admin', 'uses' => 'Admin\UserController@updateUser'));
Route::get('/admin/crear-entrada', array('as' => 'createPost', 'middleware' => 'admin', 'uses' => 'Admin\PostController@createPost'));
Route::post('/admin/guardar-entrada', array('as' => 'savePost', 'middleware' => 'admin', 'uses' => 'Admin\PostController@savePost'));
Route::get('/admin/editar-entrada/{post_id}', array('as' => 'editPost', 'middleware' => 'admin', 'uses' => 'Admin\PostController@editPost'));
Route::post('/admin/actualitzar-entrada/{post_id}', array('as' => 'updatePost', 'middleware' => 'admin', 'uses' => 'Admin\PostController@updatePost'));
Route::get('/admin/borrar-entrada/{post_id}', array('as' => 'deletePost', 'middleware' => 'admin', 'uses' => 'Admin\PostController@deletePost'));
Route::get('/admin/entrades/', array('as' => 'getPosts', 'middleware' => 'admin', 'uses' => 'Admin\PostController@getPosts'));
Route::get('/admin/entrades/cerca/{search?}', array('as' => 'searchAdminPost', 'middleware' => 'admin', 'uses' => 'Admin\PostController@searchAdminPost'));
Route::get('/admin/crear-categoria', array('as' => 'createCategory', 'middleware' => 'admin', 'uses' => 'Admin\CategoryController@createCategory'));
Route::post('/admin/guardar-categoria', array('as' => 'saveCategory', 'middleware' => 'admin', 'uses' => 'Admin\CategoryController@saveCategory'));
Route::get('/admin/editar-categoria/{category_id}', array('as' => 'editCategory', 'middleware' => 'admin', 'uses' => 'Admin\CategoryController@editCategory'));
Route::post('/admin/actualitzar-categoria/{category_id}', array('as' => 'updateCategory', 'middleware' => 'admin', 'uses' => 'Admin\CategoryController@updateCategory'));
Route::get('/admin/borrar-categoria/{category_id}', array('as' => 'deleteCategory', 'middleware' => 'admin', 'uses' => 'Admin\CategoryController@deleteCategory'));
Route::get('/admin/categories/', array('as' => 'getCategories', 'middleware' => 'admin', 'uses' => 'Admin\CategoryController@getCategories'));
Route::get('/admin', array('as' => 'admin', 'middleware' => 'admin', 'uses' => 'Admin\HomeController@index'));
